from header_common import *
from header_operations import *
from header_triggers import *
from header_scenes import *
from module_constants import *

####################################################################################################################
#  Each scene record contains the following fields:
#  1) Scene id {string}: used for referencing scenes in other files. The prefix scn_ is automatically added before each scene-id.
#  2) Scene flags {int}. See header_scenes.py for a list of available flags
#  3) Mesh name {string}: This is used for indoor scenes only. Use the keyword "none" for outdoor scenes.
#  4) Body name {string}: This is used for indoor scenes only. Use the keyword "none" for outdoor scenes.
#  5) Min-pos {(float,float)}: minimum (x,y) coordinate. Player can't move beyond this limit.
#  6) Max-pos {(float,float)}: maximum (x,y) coordinate. Player can't move beyond this limit.
#  7) Water-level {float}. 
#  8) Terrain code {string}: You can obtain the terrain code by copying it from the terrain generator screen
#  9) List of other scenes accessible from this scene {list of strings}.
#     (deprecated. This will probably be removed in future versions of the module system)
#     (In the new system passages are used to travel between scenes and
#     the passage's variation-no is used to select the game menu item that the passage leads to.)
# 10) List of chest-troops used in this scene {list of strings}. You can access chests by placing them in edit mode.
#     The chest's variation-no is used with this list for selecting which troop's inventory it will access.
#  town_1   Sargoth     #plain
#  town_2   Tihr        #steppe
#  town_3   Veluca      #steppe
#  town_4   Suno        #plain
#  town_5   Jelkala     #plain
#  town_6   Praven      #plain
#  town_7   Uxkhal      #plain
#  town_8   Reyvadin    #plain
#  town_9   Khudan      #snow
#  town_10  Tulga       #steppe
#  town_11  Curaw       #snow
#  town_12  Wercheg     #plain
#  town_13  Rivacheg    #plain
#  town_14  Halmar      #steppe
#  town_15  Yalen
#  town_16  Dhirim
#  town_17  Ichamur
#  town_18  Narra
#  town_19  Shariz
#  town_20  Durquba
#  town_21  Ahmerrad
#  town_22  Bariyye
####################################################################################################################

scenes = [
  ("random_scene",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x300028000003e8fa0000034e00004b34000059be",
    [],[]),
  ("conversation_scene",0,"none", "none", (-40,-40),(40,40),-100,"0",
    [],[]),
  ("water",0,"none", "none", (-1000,-1000),(1000,1000),-0.5,"0",
    [],[]),
  ("random_scene_steppe",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x0000000229602800000691a400003efe00004b34000059be",
    [],[], "outer_terrain_steppe"),
  ("random_scene_plain",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x0000000229602800000691a400003efe00004b34000059be",
    [],[], "outer_terrain_plain"),
  ("random_scene_snow",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x0000000229602800000691a400003efe00004b34000059be",
    [],[], "outer_terrain_snow"),
  ("random_scene_desert",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x0000000229602800000691a400003efe00004b34000059be",
    [],[], "outer_terrain_desert_b"),
  ("random_scene_steppe_forest",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x300028000003e8fa0000034e00004b34000059be",
    [],[], "outer_terrain_plain"),
  ("random_scene_plain_forest",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x300028000003e8fa0000034e00004b34000059be",
    [],[], "outer_terrain_plain"),
  ("random_scene_snow_forest",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x300028000003e8fa0000034e00004b34000059be",
    [],[], "outer_terrain_snow"),
  ("random_scene_desert_forest",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x300028000003e8fa0000034e00004b34000059be",
    [],[], "outer_terrain_desert"),
  ("camp_scene",sf_generate|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x300028000003e8fa0000034e00004b34000059be",
    [],[], "outer_terrain_plain"),
  ("camp_scene_horse_track",sf_generate|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x300028000003e8fa0000034e00004b34000059be",
    [],[], "outer_terrain_plain"),
  ("four_ways_inn",sf_generate,"none", "none", (0,0),(120,120),-100,"0x0000000030015f2b000350d4000011a4000017ee000054af",
    [],[], "outer_terrain_plain"),
  ("test_scene",sf_generate,"none", "none", (0,0),(120,120),-100,"0x0230817a00028ca300007f4a0000479400161992",
    [],[], "outer_terrain_plain"),

    
  ("tutorial",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
    

# multiplayer
  ("mp_ambush",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_ambush_fog",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_arabian_harbour",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_beach"),
  ("mp_arabian_harbour_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_beach"),
  ("mp_arabian_village",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000012002a0b20004992700006e54000007fe00001fd2",
     [],[],"outer_terrain_steppe"),
  ("mp_arabian_village_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000012002a0b20004992700006e54000007fe00001fd2",
     [],[],"outer_terrain_steppe"),
  ("mp_arabian_village_conq",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000012002a0b20004992700006e54000007fe00001fd2",
     [],[],"outer_terrain_steppe"),
  ("mp_arabian_village_conq_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000012002a0b20004992700006e54000007fe00001fd2",
     [],[],"outer_terrain_steppe"),
  ("mp_ardennes",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_snow"),
  ("mp_ardennes_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_snow"),
  ("mp_avignon",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_avignon_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  # ("mp_berezina_crossing",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e00078584000011c60000285b00005cbe",
     # [],[],"outer_terrain_plain"),
  ("mp_bavarian_river",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300005000008621800007b270000060500000d0b",
     [],[],"outer_terrain_plain"),
  ("mp_bavarian_river_cloudy",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300005000008621800007b270000060500000d0b",
     [],[],"outer_terrain_plain"),
  ("mp_beach",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000000300005000005f57b00004e92000050d600000ff9",
     [],[],"outer_terrain_beach"),
  ("mp_beach_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000000300005000005f57b00004e92000050d600000ff9",
     [],[],"outer_terrain_beach"),
  ("mp_borodino",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_borodino_morn",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_champs_elysees",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_champs_elysees_rain",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_charge_to_the_rhine",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_beach"),
  ("mp_charge_to_the_rhine_cloudy",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_beach"),
  ("mp_citadelle_napoleon",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_beach"),
  ("mp_citadelle_napoleon_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_beach"),
  ("mp_columbia_hill_farm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_columbia_farm_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_countryside",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000030024ee3400d2348591ef0ff00001bb1647fd81f",
     [],[],"outer_terrain_plain"),
  ("mp_countryside_fog",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000030024ee3400d2348591ef0ff00001bb1647fd81f",
     [],[],"outer_terrain_plain"),
  ("mp_dust",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000050000000000310c4000000000000000000000000",
     [],[],"outer_terrain_desert"),
  ("mp_dust_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000050000000000310c4000000000000000000000000",
     [],[],"outer_terrain_desert"),
  ("mp_european_city_summer",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_european_city_winter",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_snow"),
  ("mp_floodplain",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000030024ee3400d2348591ef0ff00001bb1647fd81f",
     [],[],"outer_terrain_plain"),
  ("mp_floodplain_storm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000030024ee3400d2348591ef0ff00001bb1647fd81f",
     [],[],"outer_terrain_plain"),
  ("mp_forest_pallisade",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000003007b23280037cee0000364180004cdf00000895",
     [],[],"outer_terrain_plain"),
  ("mp_forest_pallisade_fog",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000003007b23280037cee0000364180004cdf00000895",
     [],[],"outer_terrain_plain"),
  ("mp_fort_al_hafya",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001500000000004b12c000041ef00005ae800003c55",
     [],[],"outer_terrain_desert"),
  ("mp_fort_al_hafya_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001500000000004b12c000041ef00005ae800003c55",
     [],[],"outer_terrain_desert"),
  ("mp_fort_bashir",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000000500b1d158005394c00001230800072880000018f",
     [],[],"outer_terrain_desert"),
  ("mp_fort_bashir_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000000500b1d158005394c00001230800072880000018f",
     [],[],"outer_terrain_desert"),
  ("mp_fort_beaver",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_fort_beaver_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_fort_boyd",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_fort_boyd_raining",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_fort_brochet",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000003009cde1000599630000423b00005756000000af",
     [],[],"outer_terrain_plain"),
  ("mp_fort_brochet_raining",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000003009cde1000599630000423b00005756000000af",
     [],[],"outer_terrain_plain"),
  ("mp_fort_de_chartres",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001b0000000000709c2000041ef00005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_fort_de_chartres_raining",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001b0000000000709c2000041ef00005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_fort_fleetwood",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_beach"),
  ("mp_fort_fleetwood_storm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_beach"),
  ("mp_fort_george",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5 ",
     [],[],"outer_terrain_beach"),
  ("mp_fort_george_raining",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5 ",
     [],[],"outer_terrain_beach"),
  ("mp_fort_hohenfels",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_fort_hohenfels_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_fort_lyon",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_fort_lyon_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_fort_mackinaw",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000013000000080064190000041ef00005ae800003c55",
     [],[],"outer_terrain_beach"),
  ("mp_fort_mackinaw_raining",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000013000000080064190000041ef00005ae800003c55",
     [],[],"outer_terrain_beach"),
  ("mp_fort_nylas",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_fort_nylas_raining",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_fort_refleax",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_fort_refleax_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_fort_vincey",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_fort_vincey_storm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_french_farm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_french_farm_storm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_german_village",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_plain"),
  ("mp_german_village_rain",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_plain"),
  ("mp_hougoumont",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_hougoumont_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_hungarian_plains",sf_generate|sf_muddy_water,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_hungarian_plains_cloud",sf_generate|sf_muddy_water,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_theisland",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_beach"),
  ("mp_la_haye_sainte",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_la_haye_sainte_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_landshut",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e00078584000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_landshut_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e00078584000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_minden",sf_generate|sf_muddy_water,"none", "none", (0,0),(100,100),-100,"0x0000000030024ee3400d2348591ef0ff00001bb1647fd81f",
     [],[],"outer_terrain_plain"),
  ("mp_minden_night",sf_generate|sf_muddy_water,"none", "none", (0,0),(100,100),-100,"0x0000000030024ee3400d2348591ef0ff00001bb1647fd81f",
     [],[],"outer_terrain_plain"),
  ("mp_naval",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_beach"),
  ("mp_oaksfield_day",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_oaksfield_storm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_outlaws_den",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_beach"),
  ("mp_outlaws_den_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_beach"),
  ("mp_pyramids",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001500003e3000fffff0000074800005c49000021c5",
     [],[],"outer_terrain_none"),	 
  ("mp_quatre_bras",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_quatre_bras_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
     [],[],"outer_terrain_plain"),
  ("mp_river_crossing",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_river_crossing_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_roxburgh",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_roxburgh_raining",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_russian_river_day",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_russian_river_cloudy",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_russian_village",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_snow"),
  ("mp_russian_village_fog",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_snow"),
  ("mp_russian_village_conq",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_snow"),
  ("mp_russian_village_conq_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_snow"),
  ("mp_saints_isle",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_beach"),
  ("mp_saints_isle_rain",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_beach"),
  ("mp_schemmerbach",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_schemmerbach_storm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_siege_of_toulon",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000020004db18004611400005c918000397b00004c2e",
     [],[],"outer_terrain_beach"),
  ("mp_siege_of_toulon_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000020004db18004611400005c918000397b00004c2e",
     [],[],"outer_terrain_beach"),
  ("mp_sjotofta",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000003000050000046d1b0000189f00002a8380006d91",
     [],[],"outer_terrain_beach"),
  ("mp_sjotofta_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000003000050000046d1b0000189f00002a8380006d91",
     [],[],"outer_terrain_beach"),
  ("mp_slovenian_village",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_plain"),
  ("mp_slovenian_village_raining",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_plain"),
  ("mp_spanish_farm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000030000500000384e10000523400007cf5000028f8",
     [],[],"outer_terrain_steppe"),
  ("mp_spanish_farm_rain",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000030000500000384e10000523400007cf5000028f8",
     [],[],"outer_terrain_steppe"),
  ("mp_spanish_mountain_pass",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_steppe"),
  ("mp_spanish_mountain_pass_evening",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
     [],[],"outer_terrain_steppe"),
  ("mp_spanish_village",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000012002a0b20004992700006e54000007fe00001fd2",
     [],[],"outer_terrain_steppe"),
  ("mp_spanish_village_evening",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000012002a0b20004992700006e54000007fe00001fd2",
     [],[],"outer_terrain_steppe"),
  ("mp_strangefields",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_strangefields_storm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("mp_swamp",sf_generate|sf_muddy_water,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_venice",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_beach"),
  ("mp_venice_morning",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_beach"),
  ("mp_walloon_farm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_walloon_farm_night",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
     [],[],"outer_terrain_plain"),
  ("mp_wissaudorf",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000013006c883000fffff000097c30000589400003bcf",
     [],[],"outer_terrain_plain"),
  ("mp_testing_map",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),

  # # # Randoms
  
  # plain
  ("random_multi_plain_medium",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001394018dd000649920004406900002920000056d7",
    [],[], "outer_terrain_plain"),
  ("random_multi_plain_large",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x000000013a001853000aa6a40004406900002920001e4f81",
    [],[], "outer_terrain_plain"),
  ("random_multi_plain_medium_rain",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001394018dd000649920004406900002920000056d7",
    [],[], "outer_terrain_plain"),
  ("random_multi_plain_large_rain",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x000000013a001853000aa6a40004406900002920001e4f81",
    [],[], "outer_terrain_plain"),
  
  # steppe
  ("random_multi_steppe_medium", sf_generate|sf_randomize|sf_auto_entry_points, "none", "none", (0,0),(100, 100), -0.5, "0x0000000128601ae300063d8f0004406900002920001e4f81",
    [],[], "outer_terrain_steppe"),
  ("random_multi_steppe_large", sf_generate|sf_randomize|sf_auto_entry_points, "none", "none", (0,0),(100, 100), -0.5, "0x000000012a00d8630009fe7f0004406900002920001e4f81",
    [],[], "outer_terrain_steppe"),
  ("random_multi_steppe_forest_medium", sf_generate|sf_randomize|sf_auto_entry_points, "none", "none", (0,0),(100, 100), -0.5, "0x00000001a8601ae300063d8f0004406900002920001e4f81",
    [],[], "outer_terrain_steppe"),
  ("random_multi_steppe_forest_large", sf_generate|sf_randomize|sf_auto_entry_points, "none", "none", (0,0),(100, 100), -0.5, "0x00000001aa00d8630009fe7f0004406900002920001e4f81",
    [],[], "outer_terrain_steppe"),
  
  # snow
  ("random_multi_snow_medium",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001494018dd000649920004406900002920000056d7",
    [],[], "outer_terrain_snow"),
  ("random_multi_snow_medium_snow",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001494018dd000649920004406900002920000056d7",
    [],[], "outer_terrain_snow"),
  ("random_multi_snow_large",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x000000014a001853000aa6a40004406900002920001e4f81",
    [],[], "outer_terrain_snow"),
  ("random_multi_snow_large_snow",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x000000014a001853000aa6a40004406900002920001e4f81",
    [],[], "outer_terrain_snow"),
  ("random_multi_snow_forest_medium",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001c94018dd000649920004406900002920000056d7",
    [],[], "outer_terrain_snow"),
  ("random_multi_snow_forest_medium_snow",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001c94018dd000649920004406900002920000056d7",
    [],[], "outer_terrain_snow"),
  ("random_multi_snow_forest_large",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001ca001853000aa6a40004406900002920001e4f81",
    [],[], "outer_terrain_snow"),
  ("random_multi_snow_forest_large_snow",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001ca001853000aa6a40004406900002920001e4f81",
    [],[], "outer_terrain_snow"),
  
  # Desert
  ("random_multi_desert_medium", sf_generate|sf_randomize|sf_auto_entry_points, "none", "none", (0,0),(100, 100), -0.5, "0x0000000158601ae300063d8f0004406900002920001e4f81",
    [],[], "outer_terrain_desert"),
  ("random_multi_desert_large", sf_generate|sf_randomize|sf_auto_entry_points, "none", "none", (0,0),(100, 100), -0.5, "0x000000015a00d8630009fe7f0004406900002920001e4f81",
    [],[], "outer_terrain_desert"),
  ("random_multi_desert_forest_medium", sf_generate|sf_randomize|sf_auto_entry_points, "none", "none", (0,0),(100, 100), -0.5, "0x00000001d8601ae300063d8f0004406900002920001e4f81",
    [],[], "outer_terrain_desert"),
  ("random_multi_desert_forest_large", sf_generate|sf_randomize|sf_auto_entry_points, "none", "none", (0,0),(100, 100), -0.5, "0x00000001da00d8630009fe7f0004406900002920001e4f81",
    [],[], "outer_terrain_desert"),

  # Forest
  ("random_multi_forest_medium",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001b94018dd000649920004406900002920000056d7",
    [],[], "outer_terrain_plain"),
  ("random_multi_forest_medium_rain",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001b94018dd000649920004406900002920000056d7",
    [],[], "outer_terrain_plain"),
  ("random_multi_forest_large",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001ba001853000aa6a40004406900002920001e4f81",
    [],[], "outer_terrain_plain"),
  ("random_multi_forest_large_rain",sf_generate|sf_randomize|sf_auto_entry_points,"none", "none", (0,0),(240,240),-0.5,"0x00000001ba001853000aa6a40004406900002920001e4f81",
    [],[], "outer_terrain_plain"),

######################

### CUSTOM

  ("mp_custom_map_1",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",#OLD code 0x000000023002a1ba0004210900003ca000006a8900007a7b
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_2",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_3",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_4",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_5",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_6",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_7",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_8",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_9",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_10",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_11",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_12",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_13",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_14",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_15",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_16",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_17",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_18",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_19",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_20",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_21",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_22",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_23",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_24",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_25",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_26",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_27",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_28",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_29",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_30",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_31",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_32",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_33",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_34",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_35",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_36",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_37",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_38",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_39",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_40",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),  
  ("mp_custom_map_41",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_42",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_43",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_44",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_45",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_46",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_47",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_48",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_49",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_50",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_51",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_52",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_53",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_54",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_55",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_56",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_57",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_58",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_59",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_60",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_61",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_62",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_63",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_64",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_65",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_66",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_67",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_68",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_69",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_70",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_71",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_72",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_73",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_74",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_75",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_76",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_77",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_78",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_79",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_80",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_81",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_82",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_83",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_84",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_85",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_86",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_87",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_88",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_89",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_90",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_91",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_92",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_93",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_94",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_95",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_96",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_97",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_98",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_99",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
  ("mp_custom_map_100",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300040810005194a0000000000005ae800003c55",
     [],[],"outer_terrain_plain"),
     
  ("multiplayer_maps_end",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001300389800003a4ea000058340000637a0000399b",
    [],[],"outer_terrain_plain"),

  
  ("quick_battle_french_farm",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("quick_battle_landshut",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e00078584000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("quick_battle_river_crossing",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  ("quick_battle_spanish_village",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000012002a0b20004992700006e54000007fe00001fd2",
     [],[],"outer_terrain_steppe"),
  ("quick_battle_strangefields",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000130010e0e0005fd84000011c60000285b00005cbe",
     [],[],"outer_terrain_plain"),
  
  ("quick_battle_scene_1",sf_generate,"none", "none", (0,0),(120,120),-100,"0x000000013c665098000769d80000534600001adc00001118", 
    [],[], "outer_terrain_plain"),
  ("quick_battle_scene_2",sf_generate,"none", "none", (0,0),(120,120),-100,"0x000000014940095d000649920004406900002920000056d7", 
    [],[], "outer_terrain_snow"),
  ("quick_battle_scene_3",sf_generate,"none", "none", (0,0),(120,120),-100,"0x00000001bc6fd0ae000611870000202600001adc0000240e", 
    [],[], "outer_terrain_plain"),
  ("quick_battle_scene_4",sf_generate,"none", "none", (0,0),(120,120),-100,"0x0000000122f00b52000611870000175c00007b5c00003013", 
    [],[], "outer_terrain_steppe"),
  ("quick_battle_scene_6",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001db034fc50006118500001d4900007f70000073fc",
    [],[],"outer_terrain_desert_b"),
  
  ("quick_battle_maps_end",sf_generate,"none", "none", (0,0),(100,100),-100,"0x00000001db034fc50006118500001d4900007f70000073fc",
    [],[],"outer_terrain_plain"),

    
  # SP Scenes

  # Vienna battles
  ("sp_vienna",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
    [],[],"outer_terrain_plain"),
  
  # Austerlitz battles
  ("sp_sokolniz",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
    [],[],"outer_terrain_plain"),
  ("sp_auster",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000030024ee3400d2348591ef0ff00001bb1647fd81f",
    [],[],"outer_terrain_plain"),
  ("sp_sokolniz2",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
    [],[],"outer_terrain_plain"),
  
  # Dresden battles
  ("sp_dresden1",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
    [],[],"outer_terrain_plain"),
  ("sp_dresden2",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
    [],[],"outer_terrain_plain"),

  # Test crap
  ("sp_scene_1",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
    [],[],"outer_terrain_plain"),
  ("sp_scene_2",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
    [],[],"outer_terrain_plain"),
  ("sp_scene_3",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
    [],[],"outer_terrain_plain"),
  ("sp_scene_4",sf_generate,"none", "none", (0,0),(100,100),-100,"0x0000000330004563000d23480000074800005c49000021c5",
    [],[],"outer_terrain_plain"),
 
  # Camps
  ("sp_camp_austerlitz",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
    [],[],"outer_terrain_plain"),
  ("sp_camp_dresden",sf_generate,"none", "none", (0,0),(100,100),-100,"0x000000023002a1ba0004210900003ca000006a8900007a7b",
    [],[],"outer_terrain_plain"),  
 
]
