import random

from header_common import *
from header_items import *
from header_troops import *
from header_skills import *
from ID_factions import *
from ID_items import *
from ID_scenes import *

####################################################################################################################
#  Each troop contains the following fields:
#  1) Troop id (string): used for referencing troops in other files. The prefix trp_ is automatically added before each troop-id .
#  2) Troop name (string).
#  3) Plural troop name (string).
#  4) Troop flags (int). See header_troops.py for a list of available flags
#  5) Scene (int) (only applicable to heroes) For example: scn_reyvadin_castle|entry(1) puts troop in reyvadin castle's first entry point
#  6) Reserved (int). Put constant "reserved" or 0.
#  7) Faction (int)
#  8) Inventory (list): Must be a list of items
#  9) Attributes (int): Example usage:
#           str_6|agi_6|int_4|cha_5|level(5)
# 10) Weapon proficiencies (int): Example usage:
#           wp_one_handed(55)|wp_two_handed(90)|wp_polearm(36)|wp_archery(80)|wp_crossbow(24)|wp_throwing(45)
#     The function wp(x) will create random weapon proficiencies close to value x.
#     To make an expert archer with other weapon proficiencies close to 60 you can use something like:
#           wp_archery(160) | wp(60)
# 11) Skills (int): See header_skills.py to see a list of skills. Example:
#           knows_ironflesh_3|knows_power_strike_2|knows_riding_2
# 12) Face code (int): You can obtain the face code by pressing ctrl+E in face generator screen
# 13) Face code (int)(2) (only applicable to regular troops, can be omitted for heroes):
#     The game will create random faces between Face code 1 and face code 2 for generated troops
# 14) Troop image (string): If this variable is set, the troop will use an image rather than its 3D visual during the conversations
#  town_1   Sargoth
#  town_2   Tihr
#  town_3   Veluca
#  town_4   Suno
#  town_5   Jelkala
#  town_6   Praven
#  town_7   Uxkhal
#  town_8   Reyvadin
#  town_9   Khudan
#  town_10  Tulga
#  town_11  Curaw
#  town_12  Wercheg
#  town_13  Rivacheg
#  town_14  Halmar
####################################################################################################################

# Some constant and function declarations to be used below... 
# wp_one_handed () | wp_two_handed () | wp_polearm () | wp_archery () | wp_crossbow () | wp_throwing ()
def wp(x):
  n = 0
  r = 10 + int(x / 10)
#  n |= wp_one_handed(x + random.randrange(r))
#  n |= wp_two_handed(x + random.randrange(r))
#  n |= wp_polearm(x + random.randrange(r))
#  n |= wp_archery(x + random.randrange(r))
#  n |= wp_crossbow(x + random.randrange(r))
#  n |= wp_throwing(x + random.randrange(r))
  n |= wp_one_handed(x)
  n |= wp_two_handed(x)
  n |= wp_polearm(x)
  n |= wp_archery(x)
  n |= wp_crossbow(x)
  n |= wp_throwing(x)
  return n

def wpe(m,a,c,t):
   n = 0
   n |= wp_one_handed(m)
   n |= wp_two_handed(m)
   n |= wp_polearm(m)
   n |= wp_archery(a)
   n |= wp_crossbow(c)
   n |= wp_throwing(t)
   return n

def wpex(o,w,p,a,c,t):
   n = 0
   n |= wp_one_handed(o)
   n |= wp_two_handed(w)
   n |= wp_polearm(p)
   n |= wp_archery(a)
   n |= wp_crossbow(c)
   n |= wp_throwing(t)
   n |= wp_firearm(30)
   return n
   
def wp_melee(x):
  n = 0
  r = 10 + int(x / 10)
#  n |= wp_one_handed(x + random.randrange(r))
#  n |= wp_two_handed(x + random.randrange(r))
#  n |= wp_polearm(x + random.randrange(r))
  n |= wp_one_handed(x + 20)
  n |= wp_two_handed(x)
  n |= wp_polearm(x + 10)
  return n

#Skills
knows_common = knows_trade_10|knows_inventory_management_2|knows_prisoner_management_10|knows_leadership_1
def_attrib = str_12 | agi_10 | int_15 | cha_15
def_attrib_multiplayer = str_15 | agi_15 | int_15 | cha_15


#These face codes are generated by the in-game face generator.
#Enable edit mode and press ctrl+E in face generator screen to obtain face codes.


reserved = 0

no_scene = 0

swadian_face_younger_1 = 0x0000000000000001124000000020000000000000001c00800000000000000000
swadian_face_young_1   = 0x0000000400000001124000000020000000000000001c00800000000000000000
swadian_face_middle_1  = 0x0000000800000001124000000020000000000000001c00800000000000000000
swadian_face_old_1     = 0x0000000d00000001124000000020000000000000001c00800000000000000000
swadian_face_older_1   = 0x0000000fc0000001124000000020000000000000001c00800000000000000000

swadian_face_younger_2 = 0x00000000000062c76ddcdf7feefbffff00000000001efdbc0000000000000000
swadian_face_young_2   = 0x00000003c00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
swadian_face_middle_2  = 0x00000007c00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
swadian_face_old_2     = 0x0000000bc00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
swadian_face_older_2   = 0x0000000fc00062c76ddcdf7feefbffff00000000001efdbc0000000000000000

vaegir_face_younger_1 = 0x0000000000000001124000000020000000000000001c00800000000000000000
vaegir_face_young_1   = 0x0000000400000001124000000020000000000000001c00800000000000000000
vaegir_face_middle_1  = 0x0000000800000001124000000020000000000000001c00800000000000000000
vaegir_face_old_1     = 0x0000000d00000001124000000020000000000000001c00800000000000000000
vaegir_face_older_1   = 0x0000000fc0000001124000000020000000000000001c00800000000000000000

vaegir_face_younger_2 = 0x000000003f00230c4deeffffffffffff00000000001efff90000000000000000
vaegir_face_young_2   = 0x00000003bf00230c4deeffffffffffff00000000001efff90000000000000000
vaegir_face_middle_2  = 0x00000007bf00230c4deeffffffffffff00000000001efff90000000000000000
vaegir_face_old_2     = 0x0000000cbf00230c4deeffffffffffff00000000001efff90000000000000000
vaegir_face_older_2   = 0x0000000ff100230c4deeffffffffffff00000000001efff90000000000000000

khergit_face_younger_1 = 0x0000000009003109207000000000000000000000001c80470000000000000000
khergit_face_young_1   = 0x00000003c9003109207000000000000000000000001c80470000000000000000
khergit_face_middle_1  = 0x00000007c9003109207000000000000000000000001c80470000000000000000
khergit_face_old_1     = 0x0000000b89003109207000000000000000000000001c80470000000000000000
khergit_face_older_1   = 0x0000000fc9003109207000000000000000000000001c80470000000000000000

khergit_face_younger_2 = 0x000000003f0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000
khergit_face_young_2   = 0x00000003bf0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000
khergit_face_middle_2  = 0x000000077f0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000
khergit_face_old_2     = 0x0000000b3f0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000
khergit_face_older_2   = 0x0000000fff0061cd6d7ffbdf9df6ebee00000000001ffb7f0000000000000000

nord_face_younger_1 = 0x0000000000000001124000000020000000000000001c00800000000000000000
nord_face_young_1   = 0x0000000400000001124000000020000000000000001c00800000000000000000
nord_face_middle_1  = 0x0000000800000001124000000020000000000000001c00800000000000000000
nord_face_old_1     = 0x0000000d00000001124000000020000000000000001c00800000000000000000
nord_face_older_1   = 0x0000000fc0000001124000000020000000000000001c00800000000000000000

nord_face_younger_2 = 0x00000000310023084deeffffffffffff00000000001efff90000000000000000
nord_face_young_2   = 0x00000003b10023084deeffffffffffff00000000001efff90000000000000000
nord_face_middle_2  = 0x00000008310023084deeffffffffffff00000000001efff90000000000000000
nord_face_old_2     = 0x0000000c710023084deeffffffffffff00000000001efff90000000000000000
nord_face_older_2   = 0x0000000ff10023084deeffffffffffff00000000001efff90000000000000000

rhodok_face_younger_1 = 0x0000000009002003140000000000000000000000001c80400000000000000000
rhodok_face_young_1   = 0x0000000449002003140000000000000000000000001c80400000000000000000
rhodok_face_middle_1  = 0x0000000849002003140000000000000000000000001c80400000000000000000
rhodok_face_old_1     = 0x0000000cc9002003140000000000000000000000001c80400000000000000000
rhodok_face_older_1   = 0x0000000fc9002003140000000000000000000000001c80400000000000000000

rhodok_face_younger_2 = 0x00000000000062c76ddcdf7feefbffff00000000001efdbc0000000000000000
rhodok_face_young_2   = 0x00000003c00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
rhodok_face_middle_2  = 0x00000007c00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
rhodok_face_old_2     = 0x0000000bc00062c76ddcdf7feefbffff00000000001efdbc0000000000000000
rhodok_face_older_2   = 0x0000000fc00062c76ddcdf7feefbffff00000000001efdbc0000000000000000

man_face_younger_1 = 0x0000000000000001124000000020000000000000001c00800000000000000000
man_face_young_1   = 0x0000000400000001124000000020000000000000001c00800000000000000000
man_face_middle_1  = 0x0000000800000001124000000020000000000000001c00800000000000000000
man_face_old_1     = 0x0000000d00000001124000000020000000000000001c00800000000000000000
man_face_older_1   = 0x0000000fc0000001124000000020000000000000001c00800000000000000000

man_face_younger_2 = 0x000000003f0052064deeffffffffffff00000000001efff90000000000000000
man_face_young_2   = 0x00000003bf0052064deeffffffffffff00000000001efff90000000000000000
man_face_middle_2  = 0x00000007bf0052064deeffffffffffff00000000001efff90000000000000000
man_face_old_2     = 0x0000000bff0052064deeffffffffffff00000000001efff90000000000000000
man_face_older_2   = 0x0000000fff0052064deeffffffffffff00000000001efff90000000000000000

merchant_face_1    = man_face_young_1
merchant_face_2    = man_face_older_2

woman_face_1    = 0x0000000000000001000000000000000000000000001c00000000000000000000
woman_face_2    = 0x00000003bf0030067ff7fbffefff6dff00000000001f6dbf0000000000000000

swadian_woman_face_1 = 0x0000000180102006124925124928924900000000001c92890000000000000000
swadian_woman_face_2 = 0x00000001bf1000061db6d75db6b6dbad00000000001c92890000000000000000

khergit_woman_face_1 = 0x0000000180103006124925124928924900000000001c92890000000000000000
khergit_woman_face_2 = 0x00000001af1030025b6eb6dd6db6dd6d00000000001eedae0000000000000000

refugee_face1 = woman_face_1
refugee_face2 = woman_face_2
girl_face1    = woman_face_1
girl_face2    = woman_face_2

mercenary_face_1 = 0x0000000000000000000000000000000000000000001c00000000000000000000
mercenary_face_2 = 0x0000000cff00730b6db6db6db7fbffff00000000001efffe0000000000000000

vaegir_face1  = vaegir_face_young_1
vaegir_face2  = vaegir_face_older_2

bandit_face1  = man_face_young_1
bandit_face2  = man_face_older_2

undead_face1  = 0x00000000002000000000000000000000
undead_face2  = 0x000000000020010000001fffffffffff

#NAMES:
#

tf_guarantee_all = tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_helmet|tf_guarantee_horse|tf_guarantee_shield|tf_guarantee_ranged
tf_guarantee_all_wo_ranged = tf_guarantee_boots|tf_guarantee_armor|tf_guarantee_gloves|tf_guarantee_helmet|tf_guarantee_horse|tf_guarantee_shield


troops = [
  ["player","Player","Player",tf_hero|tf_unmoveable_in_party_window,no_scene,reserved,fac_player_faction,
   [],
   str_12|agi_9|int_4|cha_4,wp(100),0,0x000000018000000136db6db6db6db6db00000000001db6db0000000000000000],
  ["multiplayer_profile_troop_male","multiplayer_profile_troop_male","multiplayer_profile_troop_male", tf_hero|tf_guarantee_all, 0, 0,fac_commoners,
   [itm_character_uniform,itm_french_voltigeur_officer_pants,itm_french_versailles,itm_french_briquet_garde],
   0, 0, 0, 0x000000018000000136db6db6db6db6db00000000001db6db0000000000000000],
  ["multiplayer_profile_troop_female","multiplayer_profile_troop_female","multiplayer_profile_troop_female", tf_hero|tf_female|tf_guarantee_all, 0, 0,fac_commoners,
   [itm_character_uniform,itm_french_voltigeur_officer_pants,itm_french_versailles,itm_french_briquet_garde],
   0, 0, 0, 0x000000018000000136db6db6db6db6db00000000001db6db0000000000000000],
  ["temp_troop","Temp Troop","Temp Troop",tf_hero,no_scene,reserved,fac_commoners,[],def_attrib,0,knows_common|knows_inventory_management_10,0],

####################################################################################################################
# Troops before this point are hardwired into the game and their order should not be changed!
####################################################################################################################

# These are used as arrays in the scripts.
  ["temp_array_a","{!}temp_array_a","{!}temp_array_a",tf_hero|tf_inactive, 0,reserved,  fac_neutral,[],def_attrib|level(18),wp(60),knows_common, 0],
  ["multiplayer_data","{!}multiplayer_data","{!}multiplayer_data",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["welcomed_players","{!}welcomed_players","{!}welcomed_players",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],


#Multiplayer ai troops
  # MM
  ["british_infantry_ai","British Line Infantry","Line Infantry",tf_guarantee_all,0,0,fac_britain,
   [itm_british_infantry_ranker,itm_french_voltigeur_officer_pants,itm_33_stovepipe,itm_british_brown_bess,itm_bullets],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry2_ai","German Line Infantry","German Line Infantry",tf_guarantee_all,0,0,fac_britain,
   [itm_british_kgl_ranker,itm_french_voltigeur_officer_pants,itm_british_kgl_shako_ranker,itm_british_brown_bess,itm_bullets],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_highlander_ai","British Highland Infantry","Highland Infantry",tf_guarantee_all,0,0,fac_britain,
   [itm_british_highland_ranker,itm_british_highland_kilt,itm_british_highland_kilt_2,itm_british_highland_bonnet_ranker,itm_british_brown_bess,itm_bullets],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_foot_guard_ai","British Foot Guard","Foot Guards",tf_guarantee_all,0,0,fac_britain,
   [itm_british_guard_ranker,itm_british_coldstream_pants,itm_british_guard_shako_ranker,itm_british_brown_bess,itm_bullets],
   def_attrib|level(20),wpex(70,5,170,5,130,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_infantry_ai","British Light Infantry","Light Infantry",tf_guarantee_all,0,0,fac_britain,
   [itm_british_light_ranker,itm_french_voltigeur_officer_pants,itm_british_light_shako_ranker,itm_british_brown_bess,itm_bullets],
   def_attrib|level(20),wpex(40,5,90,5,170,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_rifle_ai","British Rifleman","Riflemen",tf_guarantee_all,0,0,fac_britain,
   [itm_british_rifle_ranker,itm_british_rifle_pants_green,itm_british_rifle_pants_grey,itm_british_rifle_pants_rolled,itm_british_rifle_shako_ranker,itm_british_rifle_shako_ranker,itm_british_rifle_shako_ranker,itm_british_rifle_beret,itm_british_rifle_beret_2,itm_british_baker_rifle,itm_bullets,itm_british_baker_bayonet],
   def_attrib|level(20),wpex(30,5,90,5,170,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_hussar_ai","British Hussar","Hussars",tf_mounted|tf_guarantee_all,0,0,fac_britain,
   [itm_british_kgl_hussar_ranker,itm_british_kgl_hussar_pants,itm_british_kgl_hussar_bearskin,itm_british_light_cav_sabre,itm_kgl_horse_britain],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_dragoon_ai","British Light Dragoon","Light Dragoons",tf_mounted|tf_guarantee_all,0,0,fac_britain,
   [itm_british_light_dragoon,itm_british_light_dragoon_pants,itm_british_lightdragoon_shako_ranker,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_russian_dragoon_musket_ai,itm_bullets,itm_lightdragoon_horse_britain_1,itm_lightdragoon_horse_britain_2,itm_lightdragoon_horse_britain_3,itm_lightdragoon_horse_britain_4],
   def_attrib|level(20),wpex(90,5,30,5,135,5),knows_common|knows_riding_4|knows_ironflesh_2|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_dragoon_ai","British Dragoon","Heavy Dragoons",tf_mounted|tf_guarantee_all,0,0,fac_britain,
   [itm_british_inniskilling_ranker,itm_british_cav_pants,itm_british_iniskilling_helmet_ranker,itm_br_cavalry_gloves,itm_british_heavy_cav_sword,itm_heavydragoon_horse_britain],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_horseguard_ai","British Horse Guard","Horse Guards",tf_mounted|tf_guarantee_all,0,0,fac_britain,
   [itm_british_blue_ranker,itm_british_cav_pants,itm_british_lifeguard_helmet_ranker,itm_br_horseguard_gloves,itm_british_heavy_cav_sword,itm_heavy_horse_britain],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_ship_ai","British Sailor","Sailors",tf_guarantee_all,0,0,fac_britain,
   [itm_sailor_pants,itm_british_seaman_hat,itm_british_seaman_hat_2,itm_british_musician_sword_invis,itm_british_baker_bayonet,itm_russian_peasant_axe,itm_russian_peasant_knife,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_sapper_axe_ship,itm_sapper_axe_ship,itm_sapper_axe_rus_ship,itm_russian_peasant_2handed_axe,itm_bullets,itm_russian_gusarskiy_karabin,itm_pistol_ammo,itm_british_pistol,itm_british_pistol,itm_british_pistol],
   def_attrib|level(20),wpex(40,5,80,5,80,60),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_ship_marine_ai","British Marine","Marines",tf_guarantee_all,0,0,fac_britain,
   [itm_british_royal_marine,itm_british_coldstream_pants,itm_royal_marine_hat,itm_royal_marine_hat,itm_royal_marine_hat,itm_royal_marine_hat,itm_royal_marine_beret,itm_british_brown_bess,itm_bullets],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_arty_ai","British Artillerist","Artillery (Cannon)",tf_guarantee_all,0,0,fac_britain,
   [itm_british_artillery_ranker,itm_french_voltigeur_officer_pants,itm_british_artillery_shako_ranker,itm_ramrod,itm_british_brown_bess,itm_bullets],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_arty_alt_ai","British Artillerist","Artillery (Howitzer)",tf_guarantee_all,0,0,fac_britain,
   [itm_british_artillery_ranker,itm_french_voltigeur_officer_pants,itm_british_artillery_shako_ranker,itm_ramrod,itm_british_brown_bess,itm_bullets],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_rocket_ai","British Rocketeer","Rocket Artillery",tf_guarantee_all,0,0,fac_britain,
   [itm_british_rocketeer,itm_british_rocketeer_pants,itm_british_rocket_tarleton,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_rockets],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  
  ["french_infantry_ai","French Line Infantry","Line Infantry",tf_guarantee_all,0,0,fac_france,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry2_ai","French Grenadier","Grenadiers",tf_guarantee_all,0,0,fac_france,
   [itm_french_84e_body_ranker,itm_french_basic_infantry_pants,itm_french_inf_shako_84_ranker,itm_bullets,itm_french_charleville,itm_french_briquet_fake],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_vistula_ai","Polish Line Infantry","Polish Line Infantry",tf_guarantee_all,0,0,fac_france,
   [itm_french_vistula_body_ranker,itm_french_vistula_pants,itm_french_vistula_shako_ranker,itm_bullets,itm_french_charleville,itm_french_briquet_fake],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_old_guard_ai","French Grenadier Guard","Grenadier Guards",tf_guarantee_all,0,0,fac_france,
   [itm_french_gap_body_ranker,itm_french_grap_pants,itm_french_gap_bearskin_ranker,itm_bullets,itm_french_versailles,itm_french_briquet_garde_fake,itm_officer_gloves],
   def_attrib|level(20),wpex(70,5,170,5,130,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_voltigeur_ai","French Voltigeur","Voltigeurs",tf_guarantee_all,0,0,fac_france,
   [itm_french_voltigeur_body_ranker,itm_french_voltigeur_officer_pants,itm_french_voltigeur_pants,itm_french_voltigeur_shako_ranker,itm_bullets,itm_french_charleville,itm_french_briquet_fake],
   def_attrib|level(20),wpex(40,5,90,5,170,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_hussar_ai","French Hussar","Hussars",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_hussards_ranker,itm_french_hussards_ranker_pants,itm_french_hussar_shako_ranker,itm_french_light_cav_sabre,itm_hussar_horse_french],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_lancer_ai","Polish Lancer","Polish Lancers",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_lancer_body_ranker,itm_french_lancer_pants,itm_french_ldlg_czapka_ranker,itm_fr_cuirassier_gloves,itm_french_lance,itm_french_light_cav_sabre_garde,itm_lancer_horse_french],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_dragoon_ai","French Dragoon","Dragoons",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_fr_cuirassier_gloves,itm_french_mousquiton_ai,itm_french_mousquiton_light_ai,itm_french_dragoon_musket_ai,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_french],
   def_attrib|level(20),wpex(100,5,30,5,100,5),knows_common|knows_riding_3|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_cuirassier_ai","French Cuirassier","Cuirassiers",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_cuirassier_ranker,itm_rus_horse_guard_pants,itm_french_cuirassier_helmet,itm_fr_cuirassier_gloves,itm_french_line_cav_sabre,itm_cuirassier_horse_french,itm_rus_horse_guard_pants],
   def_attrib|level(20),wpex(120,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_carabineer_ai","French Carabinier","Carabiniers",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_carabineer_ranker,itm_rus_horse_guard_pants,itm_french_carabineer_helmet,itm_fr_cuirassier_gloves,itm_french_carabineer_sword,itm_carabineer_horse_french],
   def_attrib|level(20),wpex(120,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_grenadier_a_cheval_ai","French Horse Grenadier","Horse Grenadiers",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_grenadiers_a_cheval_body_ranker,itm_french_grenadiers_a_cheval_pants,itm_grach_bearskin_ranker,itm_fr_cuirassier_gloves,itm_french_heavy_cav_sabre_garde,itm_heavy_horse_french],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_ship_ai","French Sailor","Sailors",tf_guarantee_all,0,0,fac_france,
   [itm_french_sailor_pants,itm_french_seaman_hat,itm_french_seaman_hat,itm_french_seaman_hat_2,itm_french_briquet,itm_french_sappeur_sword,itm_russian_peasant_axe,itm_russian_peasant_knife,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_sapper_axe_ship,itm_sapper_axe_rus_ship,itm_sapper_axe_rus_ship,itm_russian_peasant_2handed_axe,itm_bullets,itm_russian_gusarskiy_karabin,itm_pistol_ammo,itm_french_pistol_1766,itm_french_pistol_1766,itm_french_pistol_1766],
   def_attrib|level(20),wpex(40,5,80,5,80,60),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_ship_marine_ai","French Marine","Marines",tf_guarantee_all,0,0,fac_france,
   [itm_french_equipage_batallion,itm_french_equipage_batallion_pants,itm_french_marine_hat,itm_french_charleville,itm_bullets],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_arty_ai","French Artillerist","Artillery (Cannon)",tf_guarantee_all,0,0,fac_france,
   [itm_french_art_ranker_body,itm_french_art_ranker_body_alt,itm_french_art_ranker_pants,itm_french_artillery_bearskin_ranker,itm_ramrod,itm_bullets,itm_french_charleville],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_arty_alt_ai","French Artillerist","Artillery (Howitzer)",tf_guarantee_all,0,0,fac_france,
   [itm_french_art_ranker_body,itm_french_art_ranker_body_alt,itm_french_art_ranker_pants,itm_french_artillery_bearskin_ranker,itm_ramrod,itm_bullets,itm_french_charleville],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  
  ["prussian_infantry_ai","Prussian Line Infantry","Line Infantry (Brandenburg)",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_infantry_ranker,itm_prussian_infantry_pants,itm_prussian_shako,itm_prussian_shako_2,itm_russian_briquet_1807_black_fake,itm_prussian_potsdam,itm_bullets],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry2_ai","Prussian Line Infantry","Line Infantry (Rhen)",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_infantry2_ranker,itm_prussian_infantry_pants,itm_prussian_shako,itm_prussian_shako_2,itm_prussian_infantry2_hat,itm_russian_briquet_1807_black_fake,itm_prussian_potsdam,itm_bullets],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_kurmark_ai","Prussian Landwehr","Landwehr",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_landwehr_ranker,itm_prussian_landwehr_ranker_alt,itm_prussian_landwehr_pants,itm_prussian_landwehr_hat,itm_prussian_landwehr_hat_2,itm_prussian_landwehr_hat_3,itm_russian_briquet_1807_landwehr_fake,itm_russian_peasant_axe_landwehr_fake,itm_prussian_potsdam,itm_bullets],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_freikorps_ai","Prussian Freikorps","Freikorps",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_freikorps_ranker,itm_prussian_freikorps_pants,itm_prussian_shako_2,itm_russian_briquet_1807_black_blackbelt_fake,itm_prussian_potsdam,itm_bullets],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_15_ai","Prussian Foot Guard","Foot Guards",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_guard_ranker,itm_austrian_officer_boots,itm_rus_infantry_pants2,itm_prussian_guard_ranker_shako,itm_russian_briquet_1807_black_fake,itm_prussian_potsdam,itm_bullets],
   def_attrib|level(20),wpex(70,5,170,5,130,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_rifle_ai","Prussian Jaeger","Jaegers",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_jaeger_ranker,itm_prussian_jaeger_ranker_alt,itm_prussian_jaeger_pants,itm_prussian_shako_2,itm_russian_jaeger_bayonet_jaeger,itm_russian_rifle_1805,itm_bullets],
   def_attrib|level(20),wpex(30,5,90,5,170,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_dragoon_ai","Prussian Dragoon","Dragoons",tf_mounted|tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_dragoon_ranker,itm_prussian_cavalry_pants,itm_prussian_dragoon_shako_ranker,itm_british_light_cav_sabre,itm_russian_dragoon_musket_ai,itm_bullets,itm_dragoon_horse_prussia_1],
   def_attrib|level(20),wpex(100,5,30,5,100,5),knows_common|knows_riding_3|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_hussar_ai","Prussian Hussar","Hussars",tf_mounted|tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_hussar_ranker,itm_prussian_hussar_pants,itm_prussian_hussar_shako,itm_british_light_cav_sabre,itm_hussar_horse_prussia_1,itm_hussar_horse_prussia_2],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_landwehr_cav_ai","Prussian Lancer","Lancers",tf_mounted|tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_landwehr_cav_ranker,itm_prussian_landwehr_pants2,itm_prussian_landwehr_cav_shako,itm_prussian_lance,itm_british_light_cav_sabre,itm_lancer_horse_prussia_1,itm_lancer_horse_prussia_2],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_cuirassier_ai","Prussian Cuirassier","Cuirassiers",tf_mounted|tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_cuirassier_ranker,itm_prussian_cavalry_pants,itm_prussian_cavalry_pants2,itm_prussian_cuirassier_helmet,itm_french_heavy_cav_sabre_garde,itm_heavy_horse_prussia_1,itm_heavy_horse_prussia_2],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_arty_ai","Prussian Artillerist","Artillery (Cannon)",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_arty_ranker,itm_prussian_infantry_pants,itm_prussian_arty_shako_ranker,itm_ramrod,itm_bullets,itm_prussian_potsdam],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_arty_alt_ai","Prussian Artillerist","Artillery (Howitzer)",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_arty_ranker,itm_prussian_infantry_pants,itm_prussian_arty_shako_ranker,itm_ramrod,itm_bullets,itm_prussian_potsdam],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],

  ["russian_partizan_ai","Russian Partisan","Partisans",tf_guarantee_all_wo_ranged,0,0,fac_russia,
   [itm_rus_partizan1,itm_rus_partizan2,itm_rus_militia_ranker_pants,itm_rus_militia_ranker_pants1,itm_rus_opol_hat_ranker,itm_rus_partisan_hat1,itm_rus_partisan_hat2,itm_rus_partisan_hat3,itm_rus_partisan_hat4,itm_rus_partisan_hat5,itm_rus_opol_hat_ranker,itm_rus_drummer_shako,itm_bullets,itm_russian_dragoon_musket,itm_russian_peasant_fork,itm_russian_peasant_pitchfork,itm_russian_peasant_sap,itm_russian_peasant_kosa,itm_russian_peasant_kosa2,itm_birch_trunk,itm_brokenbottle,itm_russian_peasant_club,itm_russian_peasant_birch_club,itm_russian_peasant_axe,itm_russian_peasant_knife,itm_russian_peasant_serp,itm_russian_peasant_pike,itm_russian_peasant_kuvalda,itm_russian_peasant_2handed_axe,itm_russian_peasant_rogatina,itm_russian_gusarskiy_karabin],
   def_attrib|level(20),wpex(40,5,80,5,80,60),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_opol_ai","Russian Militia","Line Militia",tf_guarantee_all_wo_ranged,0,0,fac_russia,
   [itm_russian_militia_ranker,itm_rus_militia_ranker_pants,itm_rus_militia_ranker_pants1,itm_rus_opol_hat_ranker,itm_bullets,itm_russian_dragoon_musket,itm_russian_opolcheniye_pike,itm_russian_opolcheniye_pike],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_ai","Russian Line Infantry","Line Infantry",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_infantry1,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_drummer_shako,itm_bullets,itm_russian_musket_1808,itm_russian_briquet_1807_fake],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_grenadier_ai","Russian Grenadier","Grenadiers",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_gren_ranker,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_pavlovsk_ranker,itm_bullets,itm_russian_musket_1808,itm_russian_briquet_1807_fake,itm_officer_gloves],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_foot_guard_ai","Russian Foot Guard","Foot Guards",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_guard_ranker,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_guard_shako_ranker,itm_bullets,itm_russian_musket_1808,itm_russian_briquet_1807_fake,itm_officer_gloves],
   def_attrib|level(20),wpex(70,5,170,5,130,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_rifle_ai","Russian Jaeger","Jaegers",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_jaeger_ranker,itm_rus_jaeger_pants,itm_rus_jaeger_shako_ranker,itm_russian_rifle_1805,itm_bullets,itm_russian_jaeger_bayonet_jaeger],
   def_attrib|level(20),wpex(30,5,90,5,170,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_hussar_ai","Russian Hussar","Hussars",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_russian_hussar_ranker,itm_rus_hussar_pants_nco,itm_rus_hussar_shako_ranker,itm_russian_sabre_1809,itm_hussar_horse_russia],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_uhlan_ai","Russian Uhlan","Uhlans",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_russian_uhlan_ranker,itm_rus_uhlan_pants,itm_rus_uhlan_czapka_ranker,itm_russian_lancer_pike,itm_russian_sabre_1798,itm_lancer_horse_russia],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_cossack_ai","Russian Cossack","Cossacks",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_russian_cossack,itm_rus_cossack_off_pants,itm_rus_cossack_hat_ranker,itm_russian_cossack_pike,itm_russian_sabre_1798,itm_cossack_horse_russia_1,itm_cossack_horse_russia_2,itm_cossack_horse_russia_3,itm_cossack_horse_russia_4],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_dragoon_ai","Russian Dragoon","Dragoons",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_russian_dragoon_ranker,itm_rus_dragoon_pants1,itm_rus_dragoon_pants2,itm_rus_kyiv_dragoons_all,itm_russian_dragoon_musket_ai,itm_bullets,itm_russian_sword_1810,itm_dragoon_horse_russia],
   def_attrib|level(20),wpex(100,5,30,5,100,5),knows_common|knows_riding_3|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_horse_guard_ai","Russian Cavalry Guard","Cavalry Guards",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_russian_horse_guard,itm_rus_horse_guard_pants,itm_rus_chevalier_hat,itm_russian_guard_sword_1799,itm_heavy_horse_russia,itm_rus_chevgarde_gloves],
   def_attrib|level(20),wpex(120,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_arty_ai","Russian Artillerist","Artillery (Cannon)",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_arty_ranker,itm_rus_arty_pants,itm_rus_arty_shako_ranker,itm_ramrod,itm_bullets,itm_russian_musket_1808],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_arty_alt_ai","Russian Artillerist","Artillery (Howitzer)",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_arty_ranker,itm_rus_arty_pants,itm_rus_arty_shako_ranker,itm_ramrod,itm_bullets,itm_russian_musket_1808],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
   
  ["austrian_infantry_ai","Austrian Line Infantry","Line Infantry (Austria)",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_infantry,itm_aus_infantry_ranker,itm_austrian_infantry_pants,itm_bullets,itm_austrian_musket],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry2_ai","Hungarian Line Infantry","Line Infantry (Hungary)",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_infantry2,itm_aus_infantry_ranker,itm_hungarian_pants,itm_bullets,itm_austrian_musket],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenzer_ai","Austrian Grenzer","Grenzers",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_grenzer,itm_aus_grenzer_ranker,itm_hungarian_pants,itm_austrian_musket,itm_austrian_musket,itm_austrian_musket,itm_austrian_musket,itm_russian_rifle_1805,itm_russian_rifle_1805,itm_russian_gusarskiy_karabin,itm_bullets,itm_austrian_jaeger_bayonet_invis],
   def_attrib|level(20),wpex(50,5,110,5,140,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenadier_ai","Hungarian Grenadier","Grenadiers",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_grenadier,itm_austrian_grenadier_alt,itm_aus_grenadier_bearskin,itm_hungarian_pants,itm_bullets,itm_austrian_musket,itm_austrian_infantry_briquet_fake,itm_officer_gloves],
   def_attrib|level(20),wpex(70,5,170,5,130,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry_rifle_ai","Austrian Jaeger","Jaegers",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_jaeger,itm_aus_tyrol_hat,itm_austrian_jaeger_pants,itm_russian_rifle_1805,itm_bullets,itm_austrian_jaeger_bayonet],
   def_attrib|level(20),wpex(30,5,90,5,170,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_hussar_ai","Austrian Hussar","Hussars",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_hussar,itm_aus_hussard_shako_ranker,itm_hungarian_hussar_pants,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_hussar_horse_austria],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_uhlan_ai","Austrian Uhlan","Uhlans",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_uhlan,itm_aus_uhlan_czapka,itm_hungarian_uhlan_pants,itm_br_cavalry_gloves_short,itm_austrian_lance,itm_british_light_cav_sabre,itm_lancer_horse_austria],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_light_horse_ai","Austrian Chevauleger","Chevaulegers",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_lightcav,itm_aus_cavalry_helmet_ranker,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_russian_dragoon_musket_ai,itm_bullets,itm_russian_sword_1810,itm_lightcav_horse_austria],
   def_attrib|level(20),wpex(90,5,30,5,135,5),knows_common|knows_riding_4|knows_ironflesh_2|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_dragoon_ai","Austrian Dragoon","Dragoons",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_dragoon,itm_aus_cavalry_helmet_ranker,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_russian_dragoon_musket_ai,itm_bullets,itm_russian_sword_1810,itm_dragoon_horse_austria],
   def_attrib|level(20),wpex(100,5,30,5,100,5),knows_common|knows_riding_3|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_cuirassier_ai","Austrian Cuirassier","Cuirassiers",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_cuiraisser,itm_aus_cavalry_helmet_ranker,itm_austrian_cavalry_boots,itm_rus_chevgarde_gloves,itm_british_heavy_cav_sword,itm_heavy_horse_austria,itm_rus_chevgarde_gloves],
   def_attrib|level(20),wpex(120,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_arty_ai","Austrian Artillerist","Artillery (Cannon)",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_arty,itm_aus_arty_bicorn,itm_austrian_officer_boots,itm_ramrod,itm_bullets,itm_austrian_musket],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_arty_alt_ai","Austrian Artillerist","Artillery (Howitzer)",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_arty,itm_aus_arty_bicorn,itm_austrian_officer_boots,itm_ramrod,itm_bullets,itm_austrian_musket],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
   
  ["rhine_infantry_bavaria_ai","Bavarian Line Infantry","Bavarian Line Infantry",tf_guarantee_all,0,0,fac_rhine,
   [itm_bavarian_inf_ranker,itm_bavarian_infantry_pants,itm_bavarian_helmet_other_ranks,itm_bullets,itm_prussian_musket_1806,itm_french_briquet_fake],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg_ai","Wurttemberger Line Infantry","Wurttemberger Line Infantry",tf_guarantee_all,0,0,fac_rhine,
   [itm_wurttemberg_inf_ranker,itm_wurttemberg_pants_all_ranks,itm_wurttemberg_helmet_other_ranks,itm_bullets,itm_french_charleville,itm_russian_briquet_1807_black_fake],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_saxony_ai","Saxon Line Infantry","Saxon Line Infantry",tf_guarantee_all,0,0,fac_rhine,
   [itm_saxon_inf_ranker,itm_bavarian_infantry_pants,itm_saxon_inf_shako_ranker,itm_bullets,itm_prussian_musket_1806,itm_french_briquet_fake],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg2_ai","Wurttemberger Grenadier","Wurttemberger Grenadiers",tf_guarantee_all,0,0,fac_rhine,
   [itm_wurttemberg2_inf_ranker,itm_wurttemberg_grenadier_pants,itm_wurttemberg2_helmet_other_ranks,itm_bullets,itm_french_charleville,itm_french_briquet_fake],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_grenadier_guard_ai","Westphalian Grenadier Guard","Grenadier Guards",tf_guarantee_all,0,0,fac_rhine,
   [itm_westphalian_guard_ranker,itm_french_grap_pants,itm_westphalian_hat_ranker,itm_bullets,itm_french_versailles,itm_french_briquet_garde],
   def_attrib|level(20),wpex(70,5,170,5,130,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_hessen_ai","Hessian Light Infantry","Light Infantry",tf_guarantee_all,0,0,fac_rhine,
   [itm_hessian_inf_ranker,itm_hessian_infantry_pants,itm_hessian_inf_shako_ranker,itm_bullets,itm_prussian_musket_1806,itm_french_briquet_fake],
   def_attrib|level(20),wpex(30,5,90,5,170,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_bavaria_ai","Bavarian Rifleman","Riflemen",tf_guarantee_all,0,0,fac_rhine,
   [itm_bavarian_jaeger_ranker,itm_austrian_jaeger_pants,itm_bavarian_jaeger_helmet_other_ranks,itm_bullets,itm_russian_rifle_1805,itm_french_briquet_fake],
   def_attrib|level(20),wpex(30,5,90,5,170,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_mounted_jaeger_ai","Nassauer Mounted Jaeger","Mounted Jaegers",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_nassau_jaeger_ranker,itm_nassau_jaeger_pants,itm_nassau_jaeger_hat_ranker,itm_french_light_cav_sabre,itm_hussar_horse_rhine],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_uhlan_ai","Saxon Uhlan","Uhlans",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_saxon_uhlan_ranker,itm_saxon_uhlan_ranker_alt,itm_saxon_uhlan_pants,itm_saxon_uhlan_pants_alt,itm_saxon_uhlan_shako_ranker,itm_saxon_uhlan_shako_ranker_alt,itm_fr_cuirassier_gloves,itm_saxon_lance,itm_french_light_cav_sabre,itm_lancer_horse_rhine],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_dragoon_ai","Badner Light Dragoon","Light Dragoons",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_baden_dragoon_ranker,itm_badner_helmet_ranker,itm_baden_dragoon_pants,itm_fr_cuirassier_gloves,itm_russian_dragoon_musket_ai,itm_bullets,itm_french_light_cav_sabre,itm_lightcav_horse_rhine],
   def_attrib|level(20),wpex(90,5,30,5,135,5),knows_common|knows_riding_4|knows_ironflesh_2|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_cuirassier_ai","Westphalian Cuirassier","Cuirassiers",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_westphalian_cuirassier_ranker,itm_rus_horse_guard_pants,itm_westphalian_helmet_other_ranks,itm_fr_cuirassier_gloves,itm_french_line_cav_sabre,itm_cuirassier_horse_rhine],
   def_attrib|level(20),wpex(120,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_garde_du_corps_ai","Saxon Horse Guard","Horse Guards",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_saxon_garde_ranker,itm_garde_du_corps_pants_ranker,itm_saxon_helmet_other_ranks,itm_fr_cuirassier_gloves,itm_french_line_cav_sabre,itm_garde_du_corps_horse_rhine],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_arty_ai","Bavarian Artillerist","Artillery (Cannon)",tf_guarantee_all,0,0,fac_rhine,
   [itm_bavarian_artillery_ranker,itm_bavarian_artillery_pants,itm_bavarian_helmet_artillery,itm_ramrod,itm_bullets,itm_prussian_musket_1806],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_arty_alt_ai","Bavarian Artillerist","Artillery (Howitzer)",tf_guarantee_all,0,0,fac_rhine,
   [itm_bavarian_artillery_ranker,itm_bavarian_artillery_pants,itm_bavarian_helmet_artillery,itm_ramrod,itm_bullets,itm_prussian_musket_1806],
   def_attrib|level(20),wpex(50,5,50,5,80,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
   
#Multiplayer troops

  ### BRITAIN ###
  ["british_infantry","33rd Regiment of Foot","Line Infantry",tf_guarantee_all,0,0,fac_britain,
   [itm_british_infantry_ranker,itm_french_voltigeur_officer_pants,itm_33_stovepipe,itm_british_brown_bess,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry_nco","British Line Infantry","Ensign",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_infantry_sarge,itm_rus_dragoon_pants1,itm_33_stovepipe,itm_br_cavalry_gloves_short,itm_britain_colour_33rd_regt,itm_britain_colour_33rd_king,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry_officer","British Line Infantry","Officer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_infantry_officer,itm_rus_dragoon_pants1,itm_33_stovepipe,itm_br_cavalry_gloves_short,itm_british_officer_sword,itm_british_pistol,itm_pistol_ammo,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry_drum","British Line Infantry","Drummer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_infantry_drum,itm_french_voltigeur_officer_pants,itm_33_stovepipe,itm_drummer_gloves,itm_drumstick_right,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry_flute","British Line Infantry","Fifer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_infantry_flute,itm_french_voltigeur_officer_pants,itm_33_stovepipe,itm_flute,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry2","5th Line Battalion King's German Legion","Line Infantry",tf_guarantee_all,0,0,fac_britain,
   [itm_british_kgl_ranker,itm_french_voltigeur_officer_pants,itm_british_kgl_shako_ranker,itm_british_brown_bess,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry2_nco","German Line Infantry","Ensign",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_kgl_sarge,itm_rus_dragoon_pants1,itm_british_kgl_shako_officer,itm_br_cavalry_gloves_short,itm_britain_colour_kgl_regt,itm_britain_colour_kgl_king,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry2_officer","German Line Infantry","Officer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_kgl_officer,itm_rus_dragoon_pants1,itm_british_kgl_shako_officer,itm_br_cavalry_gloves_short,itm_british_officer_sword,itm_british_pistol,itm_pistol_ammo,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry2_drum","German Line Infantry","Drummer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_kgl_drum,itm_french_voltigeur_officer_pants,itm_british_kgl_shako_ranker,itm_drummer_gloves,itm_drumstick_right,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_infantry2_flute","German Line Infantry","Fifer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_kgl_flute,itm_french_voltigeur_officer_pants,itm_british_kgl_shako_ranker,itm_flute,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_highlander","42nd Regiment of Foot (Black Watch)","Line Infantry",tf_guarantee_all,0,0,fac_britain,
   [itm_british_highland_ranker,itm_british_highland_kilt,itm_british_highland_kilt_2,itm_british_highland_bonnet_ranker,itm_british_brown_bess,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,500,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_highlander_nco","British Highland Infantry","Ensign",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_highland_sarge,itm_rus_dragoon_pants1,itm_british_highland_bonnet_ensign,itm_br_cavalry_gloves_short,itm_britain_colour_42nd_regt,itm_britain_colour_42nd_king,itm_british_highlander_officer_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_highlander_officer","British Highland Infantry","Officer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_highland_officer,itm_rus_dragoon_pants1,itm_british_highland_bonnet_officer,itm_br_cavalry_gloves_short,itm_british_highlander_officer_sword,itm_british_pistol,itm_pistol_ammo,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_highlander_drum","British Highland Infantry","Drummer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_highland_drummer,itm_british_highland_kilt_officer,itm_british_highland_bonnet_drummer,itm_drummer_gloves,itm_drumstick_right,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_highlander_pipes","British Highland Infantry","Piper",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_highland_piper,itm_british_highland_piper_2,itm_british_highland_kilt_officer,itm_british_highland_bonnet_ranker,itm_bagpipe,itm_british_highlander_officer_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_foot_guard","Coldstream Regiment of Foot Guards","Foot Guard",tf_guarantee_all,0,0,fac_britain,
   [itm_british_guard_ranker,itm_british_coldstream_pants,itm_british_guard_shako_ranker,itm_british_brown_bess,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,145,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_foot_guard_nco","British Foot Guard","Ensign",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_guard_sarge,itm_rus_dragoon_pants1,itm_british_guard_shako_officer,itm_br_cavalry_gloves_short,itm_britain_colour_2nd_regt,itm_britain_colour_2nd_king,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_foot_guard_officer","British Foot Guard","Officer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_guard_officer,itm_rus_dragoon_pants1,itm_british_guard_shako_officer,itm_br_cavalry_gloves_short,itm_british_pistol,itm_pistol_ammo,itm_british_officer_sword,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_foot_guard_drum","British Foot Guard","Drummer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_guard_drum,itm_british_coldstream_pants,itm_british_guard_shako_ranker,itm_drumstick_right,itm_drummer_gloves,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_foot_guard_flute","British Foot Guard","Fifer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_guard_flute,itm_british_coldstream_pants,itm_british_guard_shako_ranker,itm_flute,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_infantry","51st (2nd Yorkshire West Riding) Regiment of Foot","Light Infantry",tf_guarantee_all,0,0,fac_britain,
   [itm_british_light_ranker,itm_french_voltigeur_officer_pants,itm_british_light_shako_ranker,itm_british_brown_bess,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_infantry_nco","British Light Infantry","Ensign",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_light_sarge,itm_rus_dragoon_pants1,itm_british_light_shako_officer,itm_br_cavalry_gloves_short,itm_britain_colour_51st_regt,itm_britain_colour_51st_king,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_infantry_officer","British Light Infantry","Officer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_light_officer,itm_rus_dragoon_pants1,itm_british_light_shako_officer,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_british_pistol,itm_pistol_ammo,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_infantry_horn","British Light Infantry","Hornist",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_light_bugler,itm_french_voltigeur_officer_pants,itm_british_light_shako_ranker,itm_horn,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_rifle","95th Regiment of Foot (Rifles)","Rifleman",tf_guarantee_all,0,0,fac_britain,
   [itm_british_rifle_ranker,itm_british_rifle_pants_green,itm_british_rifle_pants_grey,itm_british_rifle_pants_rolled,itm_british_rifle_shako_ranker,itm_british_rifle_shako_ranker,itm_british_rifle_shako_ranker,itm_british_rifle_beret,itm_british_rifle_beret_2,itm_british_baker_rifle,itm_bullets,itm_british_baker_bayonet],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_rifle_nco","British Rifleman","Sergeant",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_rifle_sarge,itm_british_rifle_pants_green,itm_british_rifle_pants_grey,itm_british_rifle_pants_rolled,itm_british_rifle_shako_ranker,itm_british_rifle_shako_ranker,itm_british_rifle_shako_ranker,itm_british_rifle_beret,itm_british_rifle_beret_2,itm_br_cavalry_gloves_short,itm_british_baker_rifle,itm_bullets,itm_british_baker_bayonet],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_rifle_officer","British Rifleman","Officer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_rifle_captain,itm_british_rifle_captain_pants,itm_british_rifle_shako_officer,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_british_pistol,itm_pistol_ammo,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_rifle_horn","British Rifleman","Hornist",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_rifle_bugler,itm_british_rifle_pants_green,itm_british_rifle_pants_grey,itm_british_rifle_pants_rolled,itm_british_rifle_shako_ranker,itm_british_rifle_shako_ranker,itm_british_rifle_shako_ranker,itm_british_rifle_beret,itm_british_rifle_beret_2,itm_horn,itm_british_baker_bayonet], #,itm_british_baker_rifle,itm_bullets
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_hussar","1st KGL Hussars","Hussar",tf_mounted|tf_guarantee_all,0,0,fac_britain,
   [itm_british_kgl_hussar_ranker,itm_british_kgl_hussar_pants,itm_british_kgl_hussar_bearskin,itm_british_light_cav_sabre,itm_kgl_horse_britain],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_hussar_nco","British Hussar","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_kgl_hussar_officer,itm_british_kgl_hussar_officer_pants,itm_british_kgl_hussar_officer_bearskin,itm_britain_colour_blues,itm_british_light_cav_sabre,itm_kgl_horse_britain],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_hussar_officer","British Hussar","Officer",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_kgl_hussar_officer,itm_british_kgl_hussar_officer_pants,itm_british_kgl_hussar_officer_bearskin,itm_british_light_cav_sabre,itm_british_pistol,itm_pistol_ammo,itm_kgl_horse_britain,itm_spyglass],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_hussar_bugle","British Hussar","Bugler",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_kgl_hussar_trumpeter,itm_british_kgl_hussar_pants,itm_british_kgl_hussar_bearskin_trumpeter,itm_british_light_cav_sabre,itm_bugle,itm_kgl_horse_britain],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_dragoon","23rd Light Dragoons","Light Horse",tf_mounted|tf_guarantee_all,0,0,fac_britain, #patch1115 fix 22/1 begin
   [itm_british_light_dragoon,itm_british_light_dragoon_pants,itm_british_lightdragoon_shako_ranker,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_british_carbine,itm_russian_dragoon_musket, itm_bullets,itm_lightdragoon_horse_britain_1,itm_lightdragoon_horse_britain_2,itm_lightdragoon_horse_britain_3,itm_lightdragoon_horse_britain_4],
   def_attrib|level(20),wpex(110,5,30,5,140,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_dragoon_nco","British Light Dragoon","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_light_dragoon,itm_british_light_dragoon_pants,itm_british_lightdragoon_shako_ranker,itm_br_cavalry_gloves_short,itm_britain_colour_blues,itm_british_light_cav_sabre, itm_lightdragoon_horse_britain_1,itm_lightdragoon_horse_britain_2,itm_lightdragoon_horse_britain_3,itm_lightdragoon_horse_britain_4],
   def_attrib|level(20),wpex(110,5,30,5,140,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_dragoon_officer","British Light Dragoon","Officer",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_light_dragoon_officer,itm_british_light_dragoon_pants,itm_british_lightdragoon_shako_officer,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_british_pistol,itm_pistol_ammo,itm_lightdragoon_horse_britain_1,itm_lightdragoon_horse_britain_2,itm_lightdragoon_horse_britain_3,itm_lightdragoon_horse_britain_4,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["british_light_dragoon_bugle","British Light Dragoon","Bugler",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_light_dragoon,itm_british_light_dragoon_pants,itm_british_lightdragoon_shako_trumpeter,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_bugle,itm_lightdragoon_horse_britain_1,itm_lightdragoon_horse_britain_2,itm_lightdragoon_horse_britain_3,itm_lightdragoon_horse_britain_4],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2], #patch1115 fix 22/1 end
  ["british_dragoon","6th (Inniskilling) Dragoons","Heavy Cavalry",tf_mounted|tf_guarantee_all,0,0,fac_britain,
   [itm_british_inniskilling_ranker,itm_british_cav_pants,itm_british_iniskilling_helmet_ranker,itm_br_cavalry_gloves,itm_british_heavy_cav_sword,itm_heavydragoon_horse_britain],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["british_dragoon_nco","British Dragoon","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_inniskilling_ranker,itm_british_cav_pants,itm_british_iniskilling_helmet_ranker,itm_br_cavalry_gloves,itm_britain_colour_blues,itm_british_heavy_cav_sword,itm_heavydragoon_horse_britain],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["british_dragoon_officer","British Dragoon","Officer",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_inniskilling_officer,itm_british_cav_pants,itm_british_iniskilling_helmet_officer,itm_br_cavalry_gloves_short,itm_british_heavy_cav_sword,itm_british_pistol,itm_pistol_ammo,itm_heavydragoon_horse_britain,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["british_dragoon_bugle","British Dragoon","Bugler",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_inniskilling_ranker,itm_british_cav_pants,itm_british_iniskilling_helmet_trumpeter,itm_br_cavalry_gloves,itm_british_heavy_cav_sword,itm_bugle,itm_heavydragoon_horse_britain],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["british_horseguard","Royal Horse Guards Blue","Heavy Cavalry",tf_mounted|tf_guarantee_all,0,0,fac_britain,
   [itm_british_blue_ranker,itm_british_cav_pants,itm_british_lifeguard_helmet_ranker,itm_br_horseguard_gloves,itm_british_heavy_cav_sword,itm_heavy_horse_britain],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["british_horseguard_nco","British Horse Guard","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_blue_ranker,itm_british_cav_pants,itm_british_lifeguard_helmet_ranker,itm_br_horseguard_gloves,itm_britain_colour_blues,itm_british_heavy_cav_sword,itm_heavy_horse_britain],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["british_horseguard_officer","British Horse Guard","Officer",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_blue_officer,itm_british_cav_pants,itm_british_lifeguard_helmet_officer,itm_br_horseguard_gloves_short,itm_british_heavy_cav_sword,itm_british_pistol,itm_pistol_ammo,itm_heavy_horse_britain,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["british_horseguard_bugle","British Horse Guard","Bugler",tf_mounted|tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_blue_ranker,itm_british_cav_pants,itm_british_lifeguard_helmet_trumpeter,itm_br_horseguard_gloves,itm_british_heavy_cav_sword,itm_bugle,itm_heavy_horse_britain],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["british_arty","Royal Foot Artillery","Artillery",tf_guarantee_all,0,0,fac_britain,
   [itm_british_artillery_ranker,itm_french_voltigeur_officer_pants,itm_british_artillery_shako_ranker,itm_ramrod,itm_cannon_lighter,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_arty_guard","Artillery Guard","Artillery Guard",tf_guarantee_all,0,0,fac_british_ranks,#patch1115 67/6
   [itm_british_artillery_ranker,itm_french_voltigeur_officer_pants,itm_british_artillery_shako_ranker,itm_british_brown_bess,itm_bullets,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_arty_nco","British Artillerist","Artillery Train",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_artillery_train,itm_british_light_dragoon_pants,itm_british_rocket_tarleton,itm_br_cavalry_gloves_short,itm_cannon_lighter,itm_arty_horse_cannon_british,itm_arty_horse_howitzer_british,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_arty_officer","British Artillerist","Officer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_artillery_officer,itm_rus_dragoon_pants1,itm_british_artillery_shako_officer,itm_br_cavalry_gloves_short,itm_british_officer_sword,itm_cannon_lighter,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_rocket","2nd Rocket Troop","Rocket Artillery",tf_guarantee_all,0,0,fac_britain,
   [itm_british_rocketeer,itm_british_rocketeer_pants,itm_british_rocket_tarleton,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_cannon_lighter,itm_rockets],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_medic","Surgeon","Surgeon",tf_guarantee_all,0,0,fac_britain,
   [itm_british_surgeon,itm_british_rifle_pants_rolled,itm_british_surgeon_bicorne,itm_bandages,itm_russian_sappeur_dagger],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_sapper","Sapper","Engineer",tf_guarantee_all,0,0,fac_britain,
   [itm_british_sapper,itm_british_sapper_pants,itm_british_guard_shako_ranker,itm_sapper_axe,itm_construction_hammer,itm_shovel,itm_russian_sappeur_dagger_invis],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_ship_marine","Ship Crew","Royal Marines",tf_guarantee_all,0,0,fac_britain,
   [itm_british_royal_marine,itm_british_coldstream_pants,itm_royal_marine_hat,itm_royal_marine_hat,itm_royal_marine_hat,itm_royal_marine_hat,itm_royal_marine_beret,itm_british_brown_bess,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_ship","Ship Crew","Ship Crew, HMS Neptune",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_sailor_pants,itm_british_seaman_hat,itm_british_seaman_hat_2,itm_british_musician_sword,itm_british_baker_bayonet,itm_russian_peasant_axe,itm_russian_peasant_knife,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_sapper_axe_ship,itm_sapper_axe_ship,itm_sapper_axe_rus_ship,itm_russian_peasant_2handed_axe,itm_bullets,itm_russian_gusarskiy_karabin,itm_pistol_ammo,itm_british_pistol,itm_british_pistol,itm_british_pistol],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,130,80),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_ship_cannon","Ship Crew","Naval Artillery",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_sailor_pants,itm_british_seaman_hat,itm_british_seaman_hat_2,itm_ramrod,itm_cannon_lighter,itm_british_musician_sword],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,130,80),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2], #patch1115 fix 32/1  
  ["british_ship_captain","Ship Crew","Post Captain, HMS Neptune",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_captain,itm_british_captain_legs,itm_british_captain_hat,itm_british_light_cav_sabre,itm_british_pistol,itm_pistol_ammo,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["wellington","Arthur Wellesley, Duke of Wellington","Commander",tf_mounted|tf_guarantee_all,0,0,fac_britain,
   [itm_british_wellington,itm_british_wellington_pants,itm_british_wellington_bicorne,itm_br_cavalry_gloves_short,itm_heavy_horse_britain,itm_french_line_cav_sabre,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],

   ### FRANCE ###
  ["french_infantry","45e Regiment d'Infanterie de ligne","Line Infantry",tf_guarantee_all,0,0,fac_france,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_nco","French Line Infantry","Eagle Bearer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_45e_body_colours,itm_french_captain_pants,itm_french_inf_bicorne_45_officer,itm_flag_france_45e,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_officer","French Line Infantry","Officer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_45e_body_officer,itm_french_captain_pants,itm_french_inf_bicorne_45_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_drum","French Line Infantry","Drummer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_45e_body_drummer,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_drummer_gloves,itm_drumstick_right,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_flute","French Line Infantry","Fifer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_45e_body_flautist,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_flute,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry2","84e Regiment d'Infanterie de ligne","Line Infantry",tf_guarantee_all,0,0,fac_france,
   [itm_french_84e_body_ranker,itm_french_basic_infantry_pants,itm_french_inf_shako_84_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry2_nco","French Grenadier","Eagle Bearer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_84e_body_sarge,itm_french_captain_pants,itm_french_inf_shako_84_colours,itm_flag_france_84e,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry2_officer","French Grenadier","Officer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_84e_body_officer,itm_fr_officer_bottefortes,itm_french_inf_shako_84_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry2_drum","French Grenadier","Drummer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_84e_body_drummer,itm_french_basic_infantry_pants,itm_french_inf_shako_84_ranker,itm_drummer_gloves,itm_drumstick_right,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry2_flute","French Grenadier","Fifer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_84e_body_flautist,itm_french_basic_infantry_pants,itm_french_inf_shako_84_ranker,itm_flute,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_vistula","Legion de la Vistule","Line Infantry",tf_guarantee_all,0,0,fac_france,
   [itm_french_vistula_body_ranker,itm_french_vistula_pants,itm_french_vistula_shako_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_vistula_colours","Polish Line Infantry","Eagle Bearer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_vistula_body_colours,itm_french_vistula_pants,itm_french_vistula_shako_colours,itm_flag_france_vistula,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_vistula_officer","Polish Line Infantry","Officer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_vistula_body_officer,itm_fr_officer_bottefortes,itm_french_vistula_shako_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_vistula_drum","Polish Line Infantry","Drummer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_vistula_body_drummer,itm_french_vistula_pants,itm_french_vistula_shako_ranker,itm_drummer_gloves,itm_drumstick_right,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_infantry_vistula_flute","Polish Line Infantry","Fifer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_vistula_body_flautist,itm_french_vistula_pants,itm_french_vistula_shako_ranker,itm_flute,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_old_guard","1er Regiment de Grenadiers de la Garde Imperiale","Foot Guard",tf_guarantee_all,0,0,fac_france,
   [itm_french_gap_body_ranker,itm_french_grap_pants,itm_french_gap_bearskin_ranker,itm_bullets,itm_french_versailles,itm_french_briquet_garde],
   def_attrib_multiplayer|level(20),wpex(50,5,145,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_old_guard_nco","French Grenadier Guard","Eagle Bearer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_gap_body_colours,itm_french_captain_pants,itm_french_gap_bearskin_colours,itm_flag_france_grenadiers,itm_french_briquet_garde],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_old_guard_officer","French Grenadier Guard","Officer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_gap_body_officer,itm_french_captain_pants,itm_french_gap_bearskin_officer,itm_french_inf_off_sabre_garde,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_old_guard_drum","French Grenadier Guard","Drummer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_grap_body_drummer,itm_french_grap_pants,itm_french_gap_bearskin_ranker,itm_drummer_gloves,itm_drumstick_right,itm_french_briquet_garde],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_old_guard_flute","French Grenadier Guard","Fifer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_grap_body_flautist,itm_french_grap_pants,itm_french_gap_bearskin_ranker,itm_flute,itm_french_briquet_garde,itm_officer_gloves],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_voltigeur","15eme Regiment d'Infanterie Legere","Light Infantry",tf_guarantee_all,0,0,fac_france,
   [itm_french_voltigeur_body_ranker,itm_french_voltigeur_officer_pants,itm_french_voltigeur_pants,itm_french_voltigeur_shako_ranker,itm_bullets,itm_french_charleville,itm_french_dragoon_musket,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_voltigeur_colours","French Voltigeur","Eagle Bearer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_voltigeur_body_sarge,itm_french_voltigeur_officer_pants,itm_french_voltigeur_pants,itm_french_voltigeur_shako_ranker,itm_flag_france_15,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_voltigeur_officer","French Voltigeur","Officer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_voltigeur_body_officer,itm_french_voltigeur_officer_pants,itm_french_voltigeur_shako_officer,itm_french_light_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_voltigeur_horn","French Voltigeur","Hornist",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_voltigeur_body_hornist,itm_french_voltigeur_officer_pants,itm_french_voltigeur_pants,itm_french_voltigeur_shako_ranker,itm_horn,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_hussar","2e Regiment de Hussards","Hussar",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_hussards_ranker,itm_french_hussards_ranker_pants,itm_french_hussar_shako_ranker,itm_french_light_cav_sabre,itm_hussar_horse_french],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_hussar_nco","French Hussar","Eagle Bearer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_hussards_nco,itm_french_hussards_ranker_pants,itm_french_hussar_shako_colours,itm_flag_france_hussard,itm_french_light_cav_sabre,itm_hussar_horse_french],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_hussar_officer","French Hussar","Officer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_hussards_officer,itm_french_hussards_officer_pants,itm_french_hussar_bearskin_officer,itm_pistol_ammo,itm_french_pistol_1777,itm_french_light_cav_off_sabre,itm_hussar_horse_french,itm_spyglass],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_hussar_trumpet","French Hussar","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_hussards_trumpeter,itm_french_hussards_trumpeter_pants,itm_french_hussar_shako_trumpeter,itm_trumpet,itm_french_light_cav_sabre,itm_hussar_horse_french_trumpet],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_lancer","Regiment de Chevau-Legers Lanciers de la Garde","Lancer",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_lancer_body_ranker,itm_french_lancer_pants,itm_french_ldlg_czapka_ranker,itm_fr_cuirassier_gloves,itm_french_lance,itm_french_light_cav_sabre_garde,itm_lancer_horse_french],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_lancer_nco","Polish Lancer","Eagle Bearer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_lancer_body_colours,itm_french_lancer_pants,itm_french_ldlg_czapka_ranker,itm_fr_cuirassier_gloves,itm_flag_france_lancier,itm_french_light_cav_sabre_garde,itm_lancer_horse_french],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_lancer_officer","Polish Lancer","Officer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_lancer_body_officer,itm_french_lancer_officer_pants,itm_french_ldlg_czapka_officer,itm_fr_cuirassier_gloves,itm_pistol_ammo,itm_french_cav_pistol,itm_french_light_cav_off_sabre,itm_lancer_horse_french,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_lancer_trumpet","Polish Lancer","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_lancer_trumpeter_body,itm_french_lancer_officer_pants,itm_french_ldlg_czapka_trumpeter,itm_fr_cuirassier_gloves,itm_trumpet,itm_french_light_cav_sabre_garde,itm_lancer_horse_french_trumpet],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_dragoon","Regiment de Dragons de l'Imperatrice","Dragoon",tf_mounted|tf_guarantee_all,0,0,fac_france, #patch1115 fix 22/2 begin
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_fr_cuirassier_gloves,itm_french_mousquiton,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_french],
   def_attrib|level(20),wpex(125,5,30,5,125,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["french_dragoon_nco","French Dragoon","Eagle Bearer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_dragoon_body_sargent,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_fr_cuirassier_gloves,itm_flag_france_dragon,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_french],
   def_attrib|level(20),wpex(125,5,30,5,125,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["french_dragoon_officer","French Dragoon","Officer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_dragoon_body_officer,itm_french_dragoon_pants,itm_french_dragoon_helmet_officer,itm_fr_cuirassier_gloves,itm_pistol_ammo,itm_french_cav_pistol,itm_french_heavy_cav_off_sabre,itm_dragoon_horse_french,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["french_dragoon_trumpet","French Dragoon","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_dragoon_body_trumpeter,itm_french_dragoon_pants,itm_french_dragoon_helmet_trumpeter,itm_fr_cuirassier_gloves,itm_trumpet,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_french_trumpet],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2], #patch1115 fix 22/2 end
  ["french_cuirassier","9eme Regiment de Cuirassiers","Cuirassier",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_cuirassier_ranker,itm_rus_horse_guard_pants,itm_french_cuirassier_helmet,itm_fr_cuirassier_gloves,itm_french_line_cav_sabre,itm_cuirassier_horse_french,itm_rus_horse_guard_pants],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_cuirassier_nco","French Cuirassier","Eagle Bearer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_cuirassier_colours,itm_rus_horse_guard_pants,itm_french_cuirassier_helmet,itm_fr_cuirassier_gloves,itm_flag_france_cuirassier,itm_french_line_cav_sabre,itm_cuirassier_horse_french],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_cuirassier_officer","French Cuirassier","Officer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_cuirassier_officer,itm_rus_horse_guard_pants,itm_french_cuirassier_helmet_officer,itm_fr_cuirassier_gloves,itm_french_cav_pistol,itm_pistol_ammo,itm_french_heavy_cav_off_sabre,itm_cuirassier_horse_french_officer,itm_spyglass],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_cuirassier_trumpet","French Cuirassier","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_fr_cuirassier_body_trumpeter,itm_rus_horse_guard_pants,itm_french_cuirassier_helmet_trumpeter,itm_fr_cuirassier_gloves,itm_trumpet,itm_french_line_cav_sabre,itm_cuirassier_horse_french_trumpet],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_carabineer","1er Regiment de Carabiniers","Carabinier",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_carabineer_ranker,itm_rus_horse_guard_pants,itm_french_carabineer_helmet,itm_fr_cuirassier_gloves,itm_french_carabineer_sword,itm_carabineer_horse_french],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_carabineer_nco","French Carabinier","Eagle Bearer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_carabineer_colours,itm_rus_horse_guard_pants,itm_french_carabineer_helmet,itm_fr_cuirassier_gloves,itm_flag_france_carab,itm_french_carabineer_sword,itm_carabineer_horse_french],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_carabineer_officer","French Carabinier","Officer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_carabineer_officer,itm_rus_horse_guard_pants,itm_french_carabineer_helmet_officer,itm_fr_cuirassier_gloves,itm_french_cav_pistol,itm_pistol_ammo,itm_french_heavy_cav_off_sabre,itm_carabineer_horse_french_officer,itm_spyglass],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_carabineer_trumpet","French Carabinier","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_fr_cuirassier_body_trumpeter,itm_rus_horse_guard_pants,itm_french_carabineer_helmet_trumpeter,itm_fr_cuirassier_gloves,itm_trumpet,itm_french_carabineer_sword,itm_carabineer_horse_french_trumpet],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_grenadier_a_cheval","Regiment de Grenadiers a Cheval de la Garde","Heavy Cavalry",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_grenadiers_a_cheval_body_ranker,itm_french_grenadiers_a_cheval_pants,itm_grach_bearskin_ranker,itm_fr_cuirassier_gloves,itm_french_heavy_cav_sabre_garde,itm_heavy_horse_french],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_grenadier_a_cheval_nco","French Horse Grenadier","Eagle Bearer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_grenadiers_a_cheval_body_colours,itm_french_grenadiers_a_cheval_pants,itm_grach_bearskin_trumpeter,itm_fr_cuirassier_gloves,itm_flag_france_cheval,itm_french_heavy_cav_sabre_garde,itm_heavy_horse_french],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_grenadier_a_cheval_officer","French Horse Grenadier","Officer",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_grenadiers_a_cheval_body_officer,itm_french_grenadiers_a_cheval_pants,itm_grach_bearskin_officer,itm_fr_cuirassier_gloves,itm_french_cav_pistol,itm_pistol_ammo,itm_french_heavy_cav_off_sabre,itm_heavy_horse_french,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_grenadier_a_cheval_trumpet","French Horse Grenadier","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_grenadier_a_cheval_body_trumpeter,itm_french_grenadiers_a_cheval_pants,itm_grach_bearskin_trumpeter,itm_fr_cuirassier_gloves,itm_trumpet,itm_french_heavy_cav_sabre_garde,itm_heavy_horse_french_trumpet],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["french_arty","L'Artillerie","Artillery",tf_guarantee_all,0,0,fac_france,
   [itm_french_art_ranker_body,itm_french_art_ranker_body_alt,itm_french_art_ranker_pants,itm_french_artillery_bearskin_ranker,itm_ramrod,itm_cannon_lighter,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_arty_guard","Artillery Guard","Artillery Guard",tf_guarantee_all,0,0,fac_french_ranks,#patch1115 67/5
   [itm_french_art_ranker_body,itm_french_art_ranker_body_alt,itm_french_art_ranker_pants,itm_french_artillery_bearskin_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_arty_nco","French Artillerist","Artillery Train",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_arty_train,itm_fr_arty_train_bottefortes,itm_french_artillery_train_shako,itm_cannon_lighter,itm_french_briquet,itm_arty_horse_cannon_french,itm_arty_horse_howitzer_french],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_arty_officer","French Artillerist","Officer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_art_officer_body,itm_fr_arty_captain_bottefortes,itm_french_artillery_bearskin_officer,itm_fr_artillery_gloves,itm_french_art_off_sword,itm_cannon_lighter,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_medic","Medecin de 2e classe","Surgeon",tf_guarantee_all,0,0,fac_france,
   [itm_french_surgeon,itm_french_surgeon_pants,itm_french_inf_bicorne_45_officer,itm_russian_sappeur_dagger,itm_bandages],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_sapper","Sapeur","Engineer",tf_guarantee_all,0,0,fac_france,
   [itm_french_sapper,itm_french_sappeur_pants,itm_french_sapper_bearskin,itm_fr_cuirassier_gloves,itm_french_sappeur_sword,itm_sapper_axe,itm_construction_hammer,itm_shovel],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_ship_marine","Ship Crew","Marine",tf_guarantee_all,0,0,fac_france,
   [itm_french_equipage_batallion,itm_french_equipage_batallion_pants,itm_french_marine_hat,itm_french_charleville,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_ship","Ship Crew","Ship Crew, Intrepide",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_sailor_pants,itm_french_seaman_hat,itm_french_seaman_hat,itm_french_seaman_hat_2,itm_french_briquet,itm_french_sappeur_sword,itm_russian_peasant_axe,itm_russian_peasant_knife,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_russian_peasant_rogatina,itm_sapper_axe_ship,itm_sapper_axe_rus_ship,itm_sapper_axe_rus_ship,itm_russian_peasant_2handed_axe,itm_bullets,itm_russian_gusarskiy_karabin,itm_pistol_ammo,itm_french_pistol_1766,itm_french_pistol_1766,itm_french_pistol_1766],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,130,80),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_ship_cannon","Ship Crew","L'Artillerie Navale",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_sailor_pants,itm_french_seaman_hat,itm_french_seaman_hat,itm_french_seaman_hat_2,itm_ramrod,itm_cannon_lighter,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,130,80),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2], #patch1115 fix 32/2  
  ["french_ship_captain","Ship Crew","Capitaine de Vaisseau, Intrepide",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_captain,itm_french_captain_pants_blue,itm_french_captain_hat,itm_french_inf_off_sabre,itm_french_officer_pistol,itm_french_pistol_1766,itm_pistol_ammo,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["napoleon","L'Empereur Napoleon Bonaparte","Commander",tf_mounted|tf_guarantee_all,0,0,fac_france,
   [itm_french_general_body_boney,itm_french_general_boots,itm_french_nappy_hat,itm_french_line_cav_sabre,itm_carabineer_horse_french_officer,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],

  ### Prussia ###
  ["prussian_infantry","8. Brandenburgische Infanterie-Regiment","Line Infantry",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_infantry_ranker,itm_prussian_infantry_pants,itm_prussian_shako,itm_prussian_shako_2,itm_russian_briquet_1807_black,itm_prussian_potsdam,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_nco","Prussian Line Infantry","Colour Bearer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_infantry_nco,itm_prussian_infantry_pants,itm_prussian_shako_colours,itm_prussian_shako_colours_2,itm_russian_briquet_1807_black,itm_prussia_colour_infantry],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_officer","Prussian Line Infantry","Officer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_infantry_officer,itm_rus_dragoon_pants1,itm_prussian_infantry_hat_officer,itm_russian_officer_sword,itm_russian_pistol,itm_pistol_ammo,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_drum","Prussian Line Infantry","Drummer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_infantry_drum,itm_prussian_infantry_pants,itm_prussian_shako,itm_prussian_shako_colours_2,itm_russian_briquet_1807_black,itm_drummer_gloves,itm_drumstick_right],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_flute","Prussian Line Infantry","Fifer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_infantry_flute,itm_prussian_infantry_pants,itm_prussian_shako,itm_prussian_shako_colours_2,itm_russian_briquet_1807_black,itm_flute],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry2","23. Rheinische Infanterie-Regiment","Line Infantry",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_infantry2_ranker,itm_prussian_infantry_pants,itm_prussian_shako,itm_prussian_shako_2,itm_prussian_infantry2_hat,itm_russian_briquet_1807_black,itm_prussian_potsdam,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry2_nco","Prussian Line Infantry","Colour Bearer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_infantry2_nco,itm_prussian_infantry_pants,itm_prussian_shako_2,itm_prussia_colour_infantry2,itm_prussian_infantry2_hat,itm_russian_briquet_1807_black],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry2_officer","Prussian Line Infantry","Officer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_infantry2_officer,itm_rus_dragoon_pants1,itm_prussian_inf_off_shako,itm_russian_officer_sword,itm_russian_pistol,itm_pistol_ammo,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry2_drum","Prussian Line Infantry","Drummer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_infantry2_drum,itm_prussian_infantry_pants,itm_prussian_shako_2,itm_prussian_infantry2_hat,itm_russian_briquet_1807_black,itm_drummer_gloves,itm_drumstick_right],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry2_flute","Prussian Line Infantry","Fifer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_infantry2_flute,itm_prussian_infantry_pants,itm_prussian_shako_2,itm_prussian_infantry2_hat,itm_russian_briquet_1807_black,itm_flute],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_kurmark","3. Kurmarkische Landwehr-Regiment","Line Infantry",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_landwehr_ranker,itm_prussian_landwehr_ranker_alt,itm_prussian_landwehr_pants,itm_prussian_landwehr_hat,itm_prussian_landwehr_hat_2,itm_prussian_landwehr_hat_3,itm_russian_briquet_1807_landwehr,itm_russian_peasant_axe_landwehr,itm_prussian_potsdam,itm_bullets,itm_russian_opolcheniye_pike],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_kurmark_nco","Prussian Landwehr","Colour Bearer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_landwehr_nco,itm_prussian_landwehr_pants,itm_prussian_landwehr_hat,itm_prussian_landwehr_hat_2,itm_prussian_landwehr_hat_3,itm_prussia_colour_landwehr,itm_russian_briquet_1807_landwehr],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_kurmark_officer","Prussian Landwehr","Officer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_landwehr_officer,itm_prussian_landwehr_pants,itm_prussian_landwehr_hat,itm_prussian_landwehr_hat_2,itm_prussian_landwehr_hat_3,itm_russian_sabre_1798,itm_russian_pistol,itm_pistol_ammo,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_kurmark_drum","Prussian Landwehr","Drummer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_landwehr_drum,itm_prussian_landwehr_pants,itm_prussian_landwehr_hat,itm_prussian_landwehr_hat_2,itm_prussian_landwehr_hat_3,itm_drumstick_right,itm_drummer_gloves,itm_russian_briquet_1807_landwehr],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_kurmark_flute","Prussian Landwehr","Fifer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_landwehr_flute,itm_prussian_landwehr_pants,itm_prussian_landwehr_hat,itm_prussian_landwehr_hat_2,itm_prussian_landwehr_hat_3,itm_flute,itm_russian_briquet_1807_landwehr],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_freikorps","Lutzowsches Freikorps","Line Infantry",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_freikorps_ranker,itm_prussian_freikorps_pants,itm_prussian_shako_2,itm_russian_briquet_1807_black_blackbelt,itm_prussian_potsdam,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_freikorps_nco","Prussian Freikorps","Colour Bearer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_freikorps_nco,itm_prussian_freikorps_pants,itm_prussian_shako_2,itm_prussia_colour_landwehr,itm_russian_briquet_1807_black_blackbelt],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_freikorps_officer","Prussian Freikorps","Officer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_freikorps_officer,itm_prussian_freikorps_pants,itm_prussian_freikorps_officer_hat,itm_russian_sabre_1798,itm_russian_pistol,itm_pistol_ammo,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_freikorps_drum","Prussian Freikorps","Drummer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_freikorps_drum,itm_prussian_freikorps_pants,itm_prussian_shako_2,itm_drumstick_right,itm_drummer_gloves,itm_russian_briquet_1807_black_blackbelt],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_freikorps_flute","Prussian Freikorps","Fifer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_freikorps_flute,itm_prussian_freikorps_pants,itm_prussian_shako_2,itm_flute,itm_russian_briquet_1807_black_blackbelt],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_15","1. Garde-Regiment zu Fuss","Foot Guard",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_guard_ranker,itm_austrian_officer_boots,itm_prussian_guard_ranker_shako,itm_russian_briquet_1807_black,itm_prussian_potsdam,itm_bullets],
   def_attrib_multiplayer|level(20),wpex(50,5,145,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_15_nco","Prussian Foot Guard","Colour Bearer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_guard_nco,itm_austrian_officer_boots,itm_prussian_guard_colours_shako,itm_prussia_colour_guard,itm_russian_briquet_1807_black],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_15_officer","Prussian Foot Guard","Officer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_guard_officer,itm_austrian_officer_boots,itm_prussian_guard_officer_shako,itm_russian_officer_sword,itm_russian_pistol,itm_pistol_ammo,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_15_drum","Prussian Foot Guard","Drummer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_guard_drummer,itm_austrian_officer_boots,itm_prussian_guard_musician_shako,itm_russian_briquet_1807_black,itm_drumstick_right,itm_drummer_gloves],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_15_flute","Prussian Foot Guard","Fifer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_guard_flute,itm_austrian_officer_boots,itm_prussian_guard_musician_shako,itm_russian_briquet_1807_black,itm_flute],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_rifle","Schlesische Schutzen","Rifleman",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_jaeger_ranker,itm_prussian_jaeger_ranker_alt,itm_prussian_jaeger_pants,itm_prussian_shako_2,itm_russian_jaeger_bayonet_jaeger,itm_russian_rifle_1805,itm_russian_dragoon_musket, itm_bullets],#patch1115 66/2
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_rifle_nco","Prussian Jaeger","Sergeant",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_jaeger_nco,itm_prussian_jaeger_pants,itm_prussian_shako_2,itm_russian_jaeger_bayonet_jaeger,itm_russian_rifle_1805,itm_russian_dragoon_musket, itm_bullets],#patch1115 66/3
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_rifle_officer","Prussian Jaeger","Officer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_jaeger_officer,itm_austrian_officer_boots,itm_prussian_jaeger_officer_shako,itm_officer_gloves,itm_russian_officer_sword,itm_russian_pistol,itm_pistol_ammo,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_infantry_rifle_horn","Prussian Jaeger","Hornist",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_jaeger_hornist,itm_prussian_jaeger_pants,itm_prussian_shako_2,itm_russian_jaeger_bayonet_jaeger,itm_horn],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_dragoon","6. Neumarkische Dragoner","Dragoon",tf_mounted|tf_guarantee_all,0,0,fac_prussia, #patch1115 fix 22/3 begin
   [itm_prussian_dragoon_ranker,itm_prussian_cavalry_pants,itm_prussian_cavalry_pants2,itm_prussian_dragoon_shako_ranker,itm_british_light_cav_sabre,itm_russian_dragoon_musket,itm_bullets,itm_dragoon_horse_prussia_1],
   def_attrib|level(20),wpex(125,5,30,5,125,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_dragoon_nco","Prussian Dragoon","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_dragoon_nco,itm_prussian_cavalry_pants,itm_prussian_cavalry_pants2,itm_prussian_dragoon_shako_ranker,itm_prussia_colour_hussard,itm_british_light_cav_sabre,itm_dragoon_horse_prussia_1],
   def_attrib|level(20),wpex(125,5,30,5,125,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_dragoon_officer","Prussian Dragoon","Officer",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_dragoon_officer,itm_prussian_cavalry_pants,itm_prussian_cavalry_pants2,itm_prussian_dragoon_shako_officer,itm_british_light_cav_sabre,itm_russian_pistol,itm_pistol_ammo,itm_dragoon_horse_prussia_1,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_dragoon_trumpet","Prussian Dragoon","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_dragoon_trumpet,itm_prussian_cavalry_pants,itm_prussian_cavalry_pants2,itm_prussian_dragoon_shako_ranker,itm_british_light_cav_sabre,itm_trumpet,itm_dragoon_horse_prussia_2],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2], #patch1115 fix 22/3 end
  ["prussian_hussar","1. Leib-Husaren-Regiment (Totenkopfhusaren)","Hussar",tf_mounted|tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_hussar_ranker,itm_prussian_hussar_pants,itm_prussian_hussar_shako,itm_british_light_cav_sabre,itm_hussar_horse_prussia_1,itm_hussar_horse_prussia_2],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_hussar_nco","Prussian Hussar","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_hussar_nco,itm_prussian_hussar_pants,itm_prussian_hussar_shako,itm_prussia_colour_hussard,itm_british_light_cav_sabre,itm_hussar_horse_prussia_1,itm_hussar_horse_prussia_2],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_hussar_officer","Prussian Hussar","Officer",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_hussar_officer,itm_prussian_hussar_officer_variant,itm_prussian_hussar_pants_officer,itm_prussian_hussar_officer_shako,itm_officer_gloves,itm_russian_pistol,itm_british_light_cav_sabre,itm_pistol_ammo,itm_hussar_horse_prussia_1,itm_hussar_horse_prussia_2,itm_spyglass],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_hussar_trumpet","Prussian Hussar","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_hussar_trumpet,itm_prussian_hussar_pants,itm_prussian_hussar_shako,itm_trumpet,itm_british_light_cav_sabre,itm_hussar_horse_prussia_1,itm_hussar_horse_prussia_2],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_landwehr_cav","Westfalische Landwehrkavallerie","Lancer",tf_mounted|tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_landwehr_cav_ranker,itm_prussian_landwehr_pants2,itm_prussian_landwehr_cav_shako,itm_prussian_lance,itm_british_light_cav_sabre,itm_lancer_horse_prussia_1,itm_lancer_horse_prussia_2],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_landwehr_cav_nco","Prussian Lancer","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_landwehr_cav_nco,itm_prussian_landwehr_pants2,itm_prussian_landwehr_cav_shako,itm_prussia_colour_hussard,itm_british_light_cav_sabre,itm_lancer_horse_prussia_1,itm_lancer_horse_prussia_2],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_landwehr_cav_officer","Prussian Lancer","Officer",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_landwehr_cav_officer,itm_rus_dragoon_pants1,itm_prussian_landwehr_cav_shako_officer,itm_british_light_cav_sabre,itm_russian_pistol,itm_pistol_ammo,itm_lancer_horse_prussia_1,itm_lancer_horse_prussia_2,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_landwehr_cav_trumpet","Prussian Lancer","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_landwehr_cav_trumpet,itm_prussian_landwehr_pants2,itm_prussian_landwehr_cav_shako,itm_trumpet,itm_british_light_cav_sabre,itm_lancer_horse_prussia_1,itm_lancer_horse_prussia_2],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_cuirassier","3. Brandenburgische Kurassier Regiment","Heavy Cavalry",tf_mounted|tf_guarantee_all,0,0,fac_prussia, #patch1115 25/4
   [itm_prussian_cuirassier_ranker,itm_prussian_cavalry_pants,itm_prussian_cavalry_pants2,itm_prussian_cuirassier_helmet,itm_french_heavy_cav_sabre_garde,itm_heavy_horse_prussia_1,itm_heavy_horse_prussia_2],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_cuirassier_nco","Prussian Cuirassier","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks, #patch1115 25/5
   [itm_prussian_cuirassier_nco,itm_prussian_cavalry_pants,itm_prussian_cavalry_pants2,itm_prussian_cuirassier_helmet,itm_french_heavy_cav_sabre_garde,itm_heavy_horse_prussia_1,itm_heavy_horse_prussia_2],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_cuirassier_officer","Prussian Cuirassier","Officer",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks, #patch1115 25/6
   [itm_prussian_cuirassier_officer,itm_prussian_cavalry_pants,itm_prussian_cavalry_pants2,itm_prussian_cuirassier_helmet,itm_fr_cuirassier_gloves,itm_french_cav_pistol,itm_pistol_ammo,itm_french_heavy_cav_off_sabre,itm_heavy_horse_prussia_1,itm_heavy_horse_prussia_2,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_cuirassier_trumpet","Prussian Cuirassier","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_prussian_ranks, #patch1115 25/7
   [itm_prussian_cuirassier_trumpet,itm_prussian_cavalry_pants,itm_prussian_cavalry_pants2,itm_prussian_cuirassier_helmet_trumpet,itm_trumpet,itm_french_heavy_cav_sabre_garde,itm_heavy_horse_prussia_1,itm_heavy_horse_prussia_2],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_arty","36. Regiment der Fussartillerie","Artillery",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_arty_ranker,itm_prussian_infantry_pants,itm_prussian_arty_shako_ranker,itm_ramrod,itm_cannon_lighter,itm_russian_briquet_1807_black_blackbelt],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_arty_guard","Artillery Guard","Artillery Guard",tf_guarantee_all,0,0,fac_prussian_ranks,#patch1115 67/4
   [itm_prussian_arty_ranker,itm_prussian_infantry_pants,itm_prussian_arty_shako_ranker,itm_prussian_potsdam,itm_bullets,itm_russian_briquet_1807_black_blackbelt],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_arty_nco","Prussian Artillerist","Artillery Train",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_arty_train,itm_prussian_cavalry_pants,itm_prussian_arty_shako_ranker,itm_cannon_lighter,itm_arty_horse_cannon_prussian,itm_arty_horse_howitzer_prussian,itm_russian_briquet_1807_black_blackbelt],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_arty_officer","Prussian Artillerist","Officer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_arty_officer,itm_rus_dragoon_pants1,itm_prussian_arty_shako_officer,itm_russian_officer_sword,itm_cannon_lighter,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_medic","Sanitaeter","Surgeon",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_surgeon,itm_prussian_blucher_pants,itm_prussian_infantry2_hat,itm_russian_sappeur_dagger,itm_bandages],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_sapper","4. Mansfelder Pionierskorps","Engineer",tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_pioneer,itm_british_coldstream_pants,itm_prussian_pioneer_shako,itm_russian_briquet_1807_black_blackbelt,itm_sapper_axe,itm_construction_hammer,itm_shovel],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_blucher","Generalfeldmarschall Gebhard von Blucher","Commander",tf_mounted|tf_guarantee_all,0,0,fac_prussia,
   [itm_prussian_blucher,itm_prussian_blucher_pants,itm_prussian_blucher_hat,itm_russian_guard_sword_1799,itm_heavy_horse_prussia_1,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
 
  ### RUSSIA ###
  ["russian_partizan","Partizani","Partisan Irregulars",tf_guarantee_all,0,0,fac_russia,
   [itm_rus_partizan1,itm_rus_partizan2,itm_rus_militia_ranker_pants,itm_rus_militia_ranker_pants1,itm_rus_opol_hat_ranker,itm_rus_partisan_hat1,itm_rus_partisan_hat2,itm_rus_partisan_hat3,itm_rus_partisan_hat4,itm_rus_partisan_hat5,itm_rus_opol_hat_ranker,itm_rus_drummer_shako,itm_bullets,itm_russian_dragoon_musket,itm_russian_peasant_fork,itm_russian_peasant_pitchfork,itm_russian_peasant_sap,itm_russian_peasant_kosa,itm_russian_peasant_kosa2,itm_birch_trunk,itm_brokenbottle,itm_russian_peasant_club,itm_russian_peasant_birch_club,itm_russian_peasant_axe,itm_russian_peasant_knife,itm_russian_peasant_serp,itm_russian_peasant_pike,itm_russian_peasant_kuvalda,itm_russian_peasant_2handed_axe,itm_russian_peasant_rogatina,itm_russian_gusarskiy_karabin],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,130,80),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_opol","Sankt-Peterburzhskoye Opolcheniye","Line Militia",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_militia_ranker,itm_rus_militia_ranker_pants,itm_rus_militia_ranker_pants1,itm_rus_opol_hat_ranker,itm_bullets,itm_russian_dragoon_musket,itm_russian_opolcheniye_pike,itm_russian_peasant_axe],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_opol_nco","Russian Militia","Colour Bearer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_militia_officer,itm_rus_militia_off_pants,itm_rus_opol_hat_officer,itm_flag_russia_opolcheniye,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2], 
  ["russian_opol_officer","Russian Militia","Officer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_militia_officer,itm_rus_militia_off_pants,itm_rus_opol_hat_officer,itm_russian_officer_sword,itm_pistol_ammo,itm_russian_pistol,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],  
  ["russian_infantry","Simbirskiy Pehotniy Polk","Line Infantry",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_infantry1,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_drummer_shako,itm_bullets,itm_russian_musket_1808,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_nco","Russian Line Infantry","Colour Bearer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_infantry_nco,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_infantry_shako_nco,itm_flag_russia_simbirsk_color,itm_flag_russia_simbirsk_white,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_officer","Russian Line Infantry","Officer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_infantry_officer,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_infantry_officer_shako,itm_russian_officer_sword,itm_pistol_ammo,itm_russian_pistol,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_drum","Russian Line Infantry","Drummer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_drummer,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_drummer_shako,itm_drummer_gloves,itm_drumstick_right,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_flute","Russian Line Infantry","Fifer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_flautist,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_drummer_shako,itm_flute,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_grenadier","Pavlovskiy Grenaderskiy Polk","Line Infantry",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_gren_ranker,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_pavlovsk_ranker,itm_bullets,itm_russian_musket_1808,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_grenadier_nco","Russian Grenadier","Colour Bearer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_gren_nco,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_pavlovsk_ranker,itm_flag_russia_pavlovsk_color,itm_flag_russia_pavlovsk_white,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_grenadier_officer","Russian Grenadier","Officer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_gren_officer,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_pavlovsk_ranker,itm_russian_officer_sword,itm_pistol_ammo,itm_russian_pistol,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_grenadier_drum","Russian Grenadier","Drummer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_drummer,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_pavlovsk_ranker,itm_drummer_gloves,itm_drumstick_right,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_grenadier_flute","Russian Grenadier","Fifer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_flautist,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_pavlovsk_ranker,itm_flute,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_foot_guard","Leib-Gvardii Preobrazhenskiy Polk","Foot Guard",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_guard_ranker,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_guard_shako_ranker,itm_bullets,itm_russian_musket_1808,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(50,5,145,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_foot_guard_nco","Russian Foot Guard","Colour Bearer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_guard_nco,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_guard_shako_nco,itm_flag_russia_preobragenskiy_color,itm_flag_russia_preobragenskiy_white,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_foot_guard_officer","Russian Foot Guard","Officer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_guard_officer,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_guard_shako_officer,itm_russian_guard_off_sword,itm_pistol_ammo,itm_russian_pistol,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_foot_guard_drum","Russian Foot Guard","Drummer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_guard_drummer,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_guard_shako_musician,itm_drummer_gloves,itm_drumstick_right,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_foot_guard_flute","Russian Foot Guard","Fifer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_guard_flautist,itm_rus_infantry_pants1,itm_rus_infantry_pants2,itm_rus_guard_shako_musician,itm_flute,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_rifle","21-y Yegerskiy Polk","Rifleman",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_jaeger_ranker,itm_rus_jaeger_pants,itm_rus_jaeger_shako_ranker,itm_russian_rifle_1805,itm_russian_dragoon_musket,itm_bullets,itm_russian_jaeger_bayonet_jaeger],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_rifle_nco","Russian Jaeger","Sergeant",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_jaeger_nco,itm_rus_jaeger_pants,itm_rus_jaeger_shako_nco,itm_russian_rifle_1805,itm_russian_dragoon_musket,itm_bullets,itm_russian_jaeger_bayonet_jaeger],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_rifle_officer","Russian Jaeger","Officer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_jaeger_officer,itm_rus_jaeger_pants,itm_rus_infantry_officer_shako,itm_russian_pistol,itm_pistol_ammo,itm_russian_officer_sword_jaeger,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_infantry_rifle_horn","Russian Jaeger","Hornist",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_jaeger_musician,itm_rus_jaeger_pants,itm_rus_jaeger_shako_ranker,itm_horn,itm_russian_briquet_1807_black_blackbelt],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_hussar","Sumskoy Gusarskiy Polk","Hussar",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_russian_hussar_ranker,itm_rus_hussar_pants_nco,itm_rus_hussar_shako_ranker,itm_russian_sabre_1809,itm_hussar_horse_russia],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_hussar_nco","Russian Hussar","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_hussar_nco,itm_rus_hussar_pants1,itm_rus_hussar_pants2,itm_rus_hussar_shako_nco,itm_flag_russia_kyiv_dragoon,itm_russian_sabre_1809,itm_hussar_horse_russia],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_hussar_officer","Russian Hussar","Officer",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_hussar_officer,itm_rus_hussar_pants_officer,itm_rus_hussar_shako_officer,itm_pistol_ammo,itm_russian_pistol,itm_russian_sabre_1809,itm_hussar_horse_russia,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_hussar_trumpet","Russian Hussar","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_hussar_trumpeter,itm_rus_hussar_pants1,itm_rus_hussar_pants2,itm_rus_hussar_shako_trumpeter,itm_trumpet,itm_russian_sabre_1809,itm_hussar_horse_russia],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_uhlan","Litovskiy Ulanskiy Polk","Lancer",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_russian_uhlan_ranker,itm_rus_uhlan_pants,itm_rus_uhlan_czapka_ranker,itm_russian_lancer_pike,itm_russian_sabre_1809,itm_lancer_horse_russia],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_uhlan_nco","Russian Uhlan","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_uhlan_nco,itm_rus_uhlan_pants,itm_rus_uhlan_czapka_nco,itm_flag_russia_kyiv_dragoon,itm_russian_sabre_1809,itm_lancer_horse_russia],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_uhlan_officer","Russian Uhlan","Officer",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_uhlan_officer,itm_rus_uhlan_pants,itm_rus_uhlan_czapka_officer,itm_pistol_ammo,itm_russian_pistol,itm_russian_sabre_1809,itm_lancer_horse_russia,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_uhlan_trumpet","Russian Uhlan","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_uhlan_trumpeter,itm_rus_uhlan_pants,itm_rus_uhlan_czapka_trumpeter,itm_trumpet,itm_russian_sabre_1809,itm_lancer_horse_russia],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_cossack","Donskoy Kazachiy Polk","Lancer",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_russian_cossack,itm_rus_cossack_off_pants,itm_rus_cossack_hat_ranker,itm_russian_cossack_pike,itm_russian_sabre_1798,itm_russian_kindjal,itm_cossack_horse_russia_1,itm_cossack_horse_russia_2,itm_cossack_horse_russia_3,itm_cossack_horse_russia_4],
   def_attrib|level(20),wpex(90,5,130,5,40,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_cossack_nco","Russian Cossack","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_cossack,itm_rus_cossack_off_pants,itm_rus_cossack_hat_nco,itm_russian_sabre_1798,itm_cossack_horse_russia_1,itm_cossack_horse_russia_2,itm_cossack_horse_russia_3,itm_cossack_horse_russia_4],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_cossack_officer","Russian Cossack","Officer",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_cossack_officer,itm_rus_cossack_off_pants,itm_rus_cossack_hat_officer,itm_pistol_ammo,itm_russian_pistol,itm_russian_sabre_1798,itm_cossack_horse_russia_1,itm_cossack_horse_russia_2,itm_cossack_horse_russia_3,itm_cossack_horse_russia_4,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_dragoon","Kievskiy Dragunskiy Polk","Dragoon",tf_mounted|tf_guarantee_all,0,0,fac_russia, #patch1115 fix 22/4 begin
   [itm_russian_dragoon_ranker,itm_rus_dragoon_pants1,itm_rus_dragoon_pants2,itm_rus_kyiv_dragoons_all,itm_russian_dragoon_musket,itm_russian_cavalry_stutzer_1803,itm_bullets,itm_russian_sword_1810,itm_dragoon_horse_russia,itm_officer_gloves],
   def_attrib|level(20),wpex(125,5,30,5,125,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["russian_dragoon_nco","Russian Dragoon","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_dragoon_nco,itm_rus_dragoon_pants1,itm_rus_dragoon_pants2,itm_rus_kyiv_dragoons_all,itm_flag_russia_kyiv_dragoon,itm_russian_sword_1810,itm_dragoon_horse_russia,itm_officer_gloves],
   def_attrib|level(20),wpex(125,5,30,5,125,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["russian_dragoon_officer","Russian Dragoon","Officer",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_dragoon_officer,itm_rus_dragoon_pants1,itm_rus_dragoon_pants2,itm_rus_kyiv_dragoons_all,itm_pistol_ammo,itm_russian_pistol,itm_russian_sword_1810,itm_dragoon_horse_russia,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["russian_dragoon_trumpet","Russian Dragoon","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_dragoon_trumpeter,itm_rus_dragoon_pants1,itm_rus_dragoon_pants2,itm_rus_kyiv_dragoons_trumpeter,itm_trumpet,itm_russian_sword_1810,itm_dragoon_horse_russia,itm_officer_gloves],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2], #patch1115 fix 22/4 end
  ["russian_horse_guard","Kavalergardskiy Polk","Cuirassier",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_russian_horse_guard,itm_rus_horse_guard_pants,itm_rus_chevalier_hat,itm_russian_guard_sword_1799,itm_heavy_horse_russia,itm_rus_chevgarde_gloves],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_horse_guard_nco","Russian Cavalry Guard","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_horse_guard_nco,itm_rus_horse_guard_pants,itm_rus_chevalier_hat,itm_flag_russia_kyiv_dragoon,itm_russian_guard_sword_1799,itm_heavy_horse_russia,itm_rus_chevgarde_gloves],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_horse_guard_officer","Russian Cavalry Guard","Officer",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_horse_guard_officer,itm_rus_horse_guard_pants,itm_rus_chevalier_hat_officer,itm_pistol_ammo,itm_russian_pistol,itm_russian_guard_sword_1799,itm_heavy_horse_russia,itm_rus_chevgarde_gloves,itm_spyglass],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_horse_guard_trumpet","Russian Cavalry Guard","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_horse_guard_trumpeter,itm_rus_dragoon_pants1,itm_rus_dragoon_pants2,itm_rus_chevalier_hat_trumpeter,itm_trumpet,itm_russian_guard_sword_1799,itm_heavy_horse_russia,itm_officer_gloves],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["russian_arty","8-ya Batarejnaya Rota","Artillery",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_arty_ranker,itm_rus_arty_pants,itm_rus_arty_shako_ranker,itm_ramrod,itm_cannon_lighter,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_arty_guard","Artillery Guard","Artillery Guard",tf_guarantee_all,0,0,fac_russian_ranks,#patch1115 67/3
   [itm_russian_arty_ranker,itm_rus_arty_pants,itm_rus_arty_shako_ranker,itm_bullets,itm_russian_musket_1808,itm_russian_briquet_1807],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_arty_nco","Russian Artillerist","Artillery Train",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_arty_nco,itm_rus_dragoon_pants2,itm_rus_arty_shako_nco,itm_cannon_lighter,itm_russian_briquet_1807,itm_arty_horse_cannon_russian,itm_arty_horse_howitzer_russian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_arty_officer","Russian Artillerist","Officer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_arty_officer,itm_rus_arty_pants,itm_rus_arty_shako_officer,itm_russian_officer_sword,itm_cannon_lighter,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_medic","Khirurg ","Surgeon",tf_guarantee_all,0,0,fac_russia,
   [itm_russian_surgeon,itm_rus_militia_off_pants,itm_rus_partisan_hat3,itm_russian_sappeur_dagger,itm_bandages],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_sapper","Saper","Engineer",tf_guarantee_all,0,0,fac_russia,
   [itm_rus_pioneer,itm_austrian_jaeger_pants,itm_rus_pioneer_shako,itm_russian_sappeur_dagger,itm_sapper_axe_rus,itm_construction_hammer,itm_shovel],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["kutuzov","Feldmarshal Mikhail Kutuzov","Commander",tf_mounted|tf_guarantee_all,0,0,fac_russia,
   [itm_kutuzov,itm_rus_kutuzov_pants,itm_kutuzov_hat,itm_russian_guard_sword_1799,itm_heavy_horse_russia,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],   
  
  ### AUSTRIA ###
  ["austrian_infantry","Infantrie Regiment Erzherzog Rudolf Nr. 14","Line Infantry",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_infantry,itm_aus_infantry_ranker,itm_austrian_infantry_pants,itm_bullets,itm_austrian_musket],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry_nco","Austrian Line Infantry","Colour Bearer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_infantry_nco,itm_aus_infantry_nco,itm_austrian_infantry_pants,itm_austria_colour_leibfahne,itm_austrian_infantry_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry_officer","Austrian Line Infantry","Officer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_infantry_officer,itm_aus_infantry_officer,itm_austrian_officer_boots,itm_russian_officer_sword,itm_pistol_ammo,itm_russian_pistol,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry_drum","Austrian Line Infantry","Drummer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_infantry_drummer,itm_aus_infantry_ranker,itm_austrian_infantry_pants,itm_drummer_gloves,itm_drumstick_right,itm_austrian_infantry_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry_flute","Austrian Line Infantry","Fifer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_infantry_fifer,itm_aus_infantry_ranker,itm_austrian_infantry_pants,itm_flute,itm_austrian_infantry_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry2","Infantrie Regiment Freiherr von Wacquant Nr. 62","Line Infantry",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_infantry2,itm_aus_infantry_ranker,itm_hungarian_pants,itm_bullets,itm_austrian_musket],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry2_nco","Hungarian Line Infantry","Colour Bearer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_infantry2_nco,itm_aus_infantry_nco,itm_hungarian_pants,itm_austria_colour_leibfahne,itm_austrian_infantry_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry2_officer","Hungarian Line Infantry","Officer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_infantry2_officer,itm_aus_infantry_officer,itm_hungarian_pants_officer,itm_russian_officer_sword,itm_pistol_ammo,itm_russian_pistol,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry2_drum","Hungarian Line Infantry","Drummer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_infantry2_drummer,itm_aus_infantry_ranker,itm_hungarian_pants,itm_drummer_gloves,itm_drumstick_right,itm_austrian_infantry_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry2_flute","Hungarian Line Infantry","Fifer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_infantry2_fifer,itm_aus_infantry_ranker,itm_hungarian_pants,itm_flute,itm_austrian_infantry_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenzer","Grenz Regiment Oguliner Nr. 3","Line/Light Infantry",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_grenzer,itm_aus_grenzer_ranker,itm_hungarian_pants,itm_austrian_musket,itm_russian_rifle_1805,itm_russian_gusarskiy_karabin,itm_bullets,itm_austrian_jaeger_bayonet_invis],
   def_attrib_multiplayer|level(20),wpex(50,5,105,5,170,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenzer_nco","Austrian Grenzer","Colour Bearer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_grenzer_nco,itm_aus_infantry_nco,itm_hungarian_pants,itm_austria_colour_ordinarfahne,itm_austrian_jaeger_bayonet_invis],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenzer_officer","Austrian Grenzer","Officer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_grenzer_officer,itm_aus_grenzer_officer,itm_hungarian_pants_officer,itm_russian_pistol,itm_pistol_ammo,itm_russian_officer_sword_jaeger,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenzer_drum","Austrian Grenzer","Drummer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_grenzer_drummer,itm_aus_grenzer_ranker,itm_hungarian_pants,itm_drummer_gloves,itm_drumstick_right,itm_austrian_jaeger_bayonet_invis],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenzer_flute","Austrian Grenzer","Fifer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_grenzer_fifer,itm_aus_grenzer_ranker,itm_hungarian_pants,itm_flute,itm_austrian_jaeger_bayonet_invis],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenadier","Grenadier Battalion Purcell","Foot Guard",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_grenadier,itm_austrian_grenadier_alt,itm_aus_grenadier_bearskin,itm_hungarian_pants,itm_bullets,itm_austrian_musket,itm_austrian_infantry_briquet,itm_officer_gloves],
   def_attrib_multiplayer|level(20),wpex(50,5,145,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenadier_nco","Hungarian Grenadier","Colour Bearer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_grenadier_nco,itm_aus_grenadier_bearskin,itm_hungarian_pants,itm_austria_colour_ordinarfahne,itm_austrian_infantry_briquet,itm_officer_gloves],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenadier_officer","Hungarian Grenadier","Officer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_grenadier_officer,itm_aus_grenadier_bearskin_officer,itm_hungarian_pants_officer,itm_russian_officer_sword,itm_pistol_ammo,itm_russian_pistol,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenadier_drum","Hungarian Grenadier","Drummer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_grenadier_drummer,itm_aus_grenadier_bearskin,itm_hungarian_pants,itm_drummer_gloves,itm_drumstick_right,itm_austrian_infantry_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_grenadier_flute","Hungarian Grenadier","Fifer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_grenadier_fifer,itm_aus_grenadier_bearskin,itm_hungarian_pants,itm_flute,itm_austrian_infantry_briquet,itm_officer_gloves],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry_rifle","Jaeger Battalion 2","Rifleman",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_jaeger,itm_aus_tyrol_hat,itm_austrian_jaeger_pants,itm_russian_rifle_1805,itm_bullets,itm_austrian_jaeger_bayonet],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry_rifle_nco","Austrian Jaeger","Sergeant",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_jaeger_nco,itm_aus_tyrol_hat,itm_austrian_jaeger_pants,itm_russian_rifle_1805,itm_bullets,itm_austrian_jaeger_bayonet],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry_rifle_officer","Austrian Jaeger","Officer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_jaeger_officer,itm_aus_tyrol_hat_officer,itm_austrian_jaeger_pants_officer,itm_russian_pistol,itm_pistol_ammo,itm_russian_officer_sword_jaeger,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_infantry_rifle_horn","Austrian Jaeger","Hornist",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_jaeger_hornist,itm_aus_tyrol_hat,itm_austrian_jaeger_pants,itm_horn,itm_austrian_jaeger_bayonet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_hussar","Husar Regiment Graf von Hessen-Homburg Nr. 4","Hussar",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_hussar,itm_aus_hussard_shako_ranker,itm_hungarian_hussar_pants,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_hussar_horse_austria],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_hussar_nco","Austrian Hussar","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_hussar_nco,itm_aus_hussard_shako_nco,itm_hungarian_hussar_pants,itm_br_cavalry_gloves_short,itm_austria_colour_ordinarfahne_cav,itm_british_light_cav_sabre,itm_hussar_horse_austria],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_hussar_officer","Austrian Hussar","Officer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_hussar_officer,itm_aus_hussard_shako_officer,itm_hungarian_hussar_pants,itm_br_cavalry_gloves_short,itm_pistol_ammo,itm_russian_pistol,itm_british_light_cav_sabre,itm_hussar_horse_austria,itm_spyglass],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_hussar_trumpet","Austrian Hussar","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_hussar_trumpet,itm_aus_hussard_shako_trumpeter,itm_hungarian_hussar_pants,itm_br_cavalry_gloves_short,itm_trumpet,itm_british_light_cav_sabre,itm_hussar_horse_austria],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_uhlan","Ulan Regiment Schwarzenberg Nr. 2","Lancer",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_uhlan,itm_aus_uhlan_czapka,itm_hungarian_uhlan_pants,itm_br_cavalry_gloves_short,itm_austrian_lance,itm_british_light_cav_sabre,itm_lancer_horse_austria],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_uhlan_nco","Austrian Uhlan","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_uhlan,itm_aus_uhlan_czapka,itm_hungarian_uhlan_pants,itm_br_cavalry_gloves_short,itm_austria_colour_ordinarfahne_cav,itm_british_light_cav_sabre,itm_lancer_horse_austria],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_uhlan_officer","Austrian Uhlan","Officer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_uhlan_officer,itm_aus_uhlan_czapka_officer,itm_hungarian_uhlan_pants,itm_br_cavalry_gloves_short,itm_pistol_ammo,itm_russian_pistol,itm_british_light_cav_sabre,itm_lancer_horse_austria,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_uhlan_trumpet","Austrian Uhlan","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_uhlan,itm_aus_uhlan_czapka_trumpeter,itm_hungarian_uhlan_pants,itm_br_cavalry_gloves_short,itm_trumpet,itm_british_light_cav_sabre,itm_lancer_horse_austria],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_light_horse","Chevauleger Regiment Furst von Hohenzollern Nr. 2","Light Horse",tf_mounted|tf_guarantee_all,0,0,fac_austria, #patch1115 fix 22/5 begin
   [itm_austrian_lightcav,itm_aus_cavalry_helmet_ranker,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_russian_dragoon_musket,itm_bullets,itm_russian_sword_1810,itm_lightcav_horse_austria],
   def_attrib|level(20),wpex(110,5,30,5,140,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_light_horse_nco","Austrian Chevauleger","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_lightcav_nco,itm_aus_cavalry_helmet_ranker,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_austria_colour_ordinarfahne_cav,itm_russian_sword_1810,itm_lightcav_horse_austria],
   def_attrib|level(20),wpex(110,5,30,5,140,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_light_horse_officer","Austrian Chevauleger","Officer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_lightcav_officer,itm_aus_cavalry_helmet_officer,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_pistol_ammo,itm_russian_pistol,itm_russian_sword_1810,itm_lightcav_horse_austria,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_light_horse_trumpet","Austrian Chevauleger","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_lightcav_trumpet,itm_aus_cavalry_helmet_trumpeter,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_trumpet,itm_russian_sword_1810,itm_lightcav_horse_austria],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_dragoon","Dragoner Regiment Erzherzog Ferdinand Nr. 5","Dragoon",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_dragoon,itm_aus_cavalry_helmet_ranker,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_russian_dragoon_musket,itm_bullets,itm_russian_sword_1810,itm_dragoon_horse_austria],
   def_attrib|level(20),wpex(125,5,30,5,125,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_dragoon_nco","Austrian Dragoon","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_dragoon_nco,itm_aus_cavalry_helmet_ranker,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_austria_colour_ordinarfahne_cav,itm_russian_sword_1810,itm_dragoon_horse_austria],
   def_attrib|level(20),wpex(125,5,30,5,125,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_dragoon_officer","Austrian Dragoon","Officer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_dragoon_officer,itm_aus_cavalry_helmet_officer,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_pistol_ammo,itm_russian_pistol,itm_russian_sword_1810,itm_dragoon_horse_austria,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_dragoon_trumpet","Austrian Dragoon","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_dragoon_trumpet,itm_aus_cavalry_helmet_trumpeter,itm_austrian_cavalry_boots,itm_br_cavalry_gloves_short,itm_trumpet,itm_russian_sword_1810,itm_dragoon_horse_austria],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2], #patch1115 fix 22/5 end
  ["austrian_cuirassier","Kurassier Regiment Kaiser Franz Nr. 1","Cuirassier",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_cuiraisser,itm_aus_cavalry_helmet_ranker,itm_austrian_cavalry_boots,itm_rus_chevgarde_gloves,itm_british_heavy_cav_sword,itm_heavy_horse_austria,itm_rus_chevgarde_gloves],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_cuirassier_nco","Austrian Cuirassier","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_cuiraisser_nco,itm_aus_cavalry_helmet_ranker,itm_austrian_cavalry_boots,itm_rus_chevgarde_gloves,itm_austria_colour_ordinarfahne_cav,itm_british_heavy_cav_sword,itm_heavy_horse_austria,itm_rus_chevgarde_gloves],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_cuirassier_officer","Austrian Cuirassier","Officer",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_cuiraisser_officer,itm_aus_cavalry_helmet_officer,itm_austrian_cavalry_boots,itm_rus_chevgarde_gloves,itm_pistol_ammo,itm_russian_pistol,itm_british_heavy_cav_sword,itm_heavy_horse_austria,itm_rus_chevgarde_gloves,itm_spyglass],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_cuirassier_trumpet","Austrian Cuirassier","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_cuiraisser_trumpet,itm_aus_cavalry_helmet_trumpeter,itm_austrian_cavalry_boots,itm_officer_gloves,itm_trumpet,itm_british_heavy_cav_sword,itm_heavy_horse_austria],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_arty","Artillerie Regiment Prinz zu Lothringen Nr. 7","Artillery",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_arty,itm_aus_arty_bicorn,itm_austrian_officer_boots,itm_ramrod,itm_cannon_lighter,itm_austrian_infantry_briquet],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_arty_guard","Artillery Guard","Artillery Guard",tf_guarantee_all,0,0,fac_austrian_ranks,#patch1115 67/2
   [itm_austrian_arty,itm_aus_arty_bicorn,itm_austrian_officer_boots,itm_bullets,itm_austrian_musket,itm_austrian_infantry_briquet],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_arty_nco","Austrian Artillerist","Artillery Train",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_arty_train,itm_aus_arty_train_hat,itm_austrian_officer_boots,itm_cannon_lighter,itm_austrian_infantry_briquet,itm_arty_horse_cannon_austrian,itm_arty_horse_howitzer_austrian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_arty_officer","Austrian Artillerist","Officer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_arty_officer,itm_aus_arty_cap_bicorn,itm_austrian_officer_boots,itm_russian_officer_sword,itm_cannon_lighter,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_medic","Sanitaeter","Surgeon",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_surgeon,itm_aus_surgeon_hat,itm_austrian_jaeger_pants_officer,itm_russian_sappeur_dagger,itm_bandages],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_sapper","Pionier-Battalion Nr. 1","Engineer",tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_pioneer,itm_aus_pioneer_hat,itm_austrian_officer_boots,itm_austrian_infantry_briquet,itm_sapper_axe,itm_construction_hammer,itm_shovel],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["schwarzenberg","Karl Philipp, Furst zu Schwarzenberg","Commander",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_schwarzenberg,itm_austrian_schwarzenberg_pants,itm_aus_shwarzenberg_bicorn,itm_british_heavy_cav_sword,itm_heavy_horse_austria,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],   

   
   ### RHINE ###
  ["rhine_infantry_bavaria","2. Infanterie-Regiment Kronprinz, Bayern","Line Infantry",tf_guarantee_all,0,0,fac_rhine,
   [itm_bavarian_inf_ranker,itm_bavarian_infantry_pants,itm_bavarian_helmet_other_ranks,itm_bullets,itm_prussian_musket_1806,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_bavaria_nco","Bavarian Line Infantry","Colour Bearer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_inf_flagcarrier,itm_bavarian_infantry_pants,itm_bavarian_helmet_flagcarrier,itm_bavarian_flag_national,itm_bavarian_flag_regimental,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_bavaria_officer","Bavarian Line Infantry","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_inf_officer,itm_bavarian_pants_officer,itm_bavarian_helmet_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_bavaria_drum","Bavarian Line Infantry","Drummer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_inf_drummer,itm_bavarian_infantry_pants,itm_bavarian_helmet_other_ranks,itm_drummer_gloves,itm_drumstick_right,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_bavaria_flute","Bavarian Line Infantry","Fifer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_inf_flutist,itm_bavarian_infantry_pants,itm_bavarian_helmet_other_ranks,itm_flute,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg","Infanterie-Reg. No.2 Herzog Wilhelm, Wurttemberg","Line Infantry",tf_guarantee_all,0,0,fac_rhine,
   [itm_wurttemberg_inf_ranker,itm_wurttemberg_pants_all_ranks,itm_wurttemberg_helmet_other_ranks,itm_bullets,itm_french_charleville,itm_russian_briquet_1807_black],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg_nco","Wurttemberger Line Infantry","Colour Bearer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_wurttemberg_inf_flagcarrier,itm_wurttemberg_pants_all_ranks,itm_wurttemberg_helmet_flagcarrier,itm_wurttemberg_flag_infantry,itm_russian_briquet_1807_black],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg_officer","Wurttemberger Line Infantry","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_wurttemberg_inf_officer,itm_wurttemberg_pants_officer,itm_wurttemberg_helmet_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg_drum","Wurttemberger Line Infantry","Drummer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_wurttemberg_inf_drummer,itm_wurttemberg_pants_all_ranks,itm_wurttemberg_helmet_other_ranks,itm_drummer_gloves,itm_drumstick_right,itm_russian_briquet_1807_black],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg_flute","Wurttemberger Line Infantry","Fifer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_wurttemberg_inf_flutist,itm_wurttemberg_pants_all_ranks,itm_wurttemberg_helmet_other_ranks,itm_flute,itm_russian_briquet_1807_black],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_saxony","Infanterie-Regiment Prinz Friedrich August, Sachsen","Line Infantry",tf_guarantee_all,0,0,fac_rhine,
   [itm_saxon_inf_ranker,itm_bavarian_infantry_pants,itm_saxon_inf_shako_ranker,itm_bullets,itm_prussian_musket_1806,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_saxony_nco","Saxon Line Infantry","Colour Bearer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_inf_nco,itm_bavarian_infantry_pants,itm_saxon_inf_shako_nco,itm_saxon_flag_infantry,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_saxony_officer","Saxon Line Infantry","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_inf_officer,itm_bavarian_pants_officer,itm_saxon_inf_shako_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_saxony_drum","Saxon Line Infantry","Drummer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_inf_drummer,itm_bavarian_infantry_pants,itm_saxon_inf_shako_ranker,itm_drummer_gloves,itm_drumstick_right,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_saxony_flute","Saxon Line Infantry","Fifer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_inf_fifer,itm_bavarian_infantry_pants,itm_saxon_inf_shako_ranker,itm_flute,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg2","Infanterie-Reg. No.4 von Franquemont, Wurttemberg","Line Infantry",tf_guarantee_all,0,0,fac_rhine,
   [itm_wurttemberg2_inf_ranker,itm_wurttemberg_grenadier_pants,itm_wurttemberg2_helmet_other_ranks,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,130,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg2_nco","Wurttemberger Grenadier","Colour Bearer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_wurttemberg2_inf_flagcarrier,itm_wurttemberg_pants_all_ranks,itm_wurttemberg2_helmet_flagcarrier,itm_wurttemberg_flag_infantry2,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg2_officer","Wurttemberger Grenadier","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_wurttemberg2_inf_officer,itm_wurttemberg_pants_officer,itm_wurttemberg2_helmet_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg2_drum","Wurttemberger Grenadier","Drummer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_wurttemberg2_inf_drummer,itm_wurttemberg_grenadier_pants,itm_wurttemberg2_helmet_other_ranks,itm_drummer_gloves,itm_drumstick_right,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_infantry_wurttemberg2_flute","Wurttemberger Grenadier","Fifer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_wurttemberg2_inf_flutist,itm_wurttemberg_grenadier_pants,itm_wurttemberg2_helmet_other_ranks,itm_flute,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_grenadier_guard","Grenadiers de la Garde, Westphalen","Foot Guard",tf_guarantee_all,0,0,fac_rhine,
   [itm_westphalian_guard_ranker,itm_french_grap_pants,itm_westphalian_hat_ranker,itm_bullets,itm_french_versailles,itm_french_briquet_garde],
   def_attrib_multiplayer|level(20),wpex(50,5,145,5,150,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_grenadier_guard_nco","Westphalian Grenadier Guard","Colour Bearer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_westphalian_guard_nco,itm_bavarian_pants_officer,itm_westphalian_hat_officer,itm_westphalian_flag_infantry,itm_french_briquet_garde,itm_officer_gloves],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_grenadier_guard_officer","Westphalian Grenadier Guard","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_westphalian_guard_officer,itm_bavarian_pants_officer,itm_westphalian_hat_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_grenadier_guard_drum","Westphalian Grenadier Guard","Drummer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_westphalian_guard_drummer,itm_french_grap_pants,itm_westphalian_hat_ranker,itm_drummer_gloves,itm_drumstick_right,itm_french_briquet_garde],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_grenadier_guard_flute","Westphalian Grenadier Guard","Fifer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_westphalian_guard_fifer,itm_french_grap_pants,itm_westphalian_hat_ranker,itm_flute,itm_french_briquet_garde],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_hessen","Infanterie-Reg. Gross- und Erbprinz, Hessen-Darmstadt","Light Infantry",tf_guarantee_all,0,0,fac_rhine,
   [itm_hessian_inf_ranker,itm_hessian_infantry_pants,itm_hessian_inf_shako_ranker,itm_bullets,itm_prussian_musket_1806,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_hessen_nco","Hessian Light Infantry","Colour Bearer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_hessian_inf_nco,itm_hessian_infantry_pants,itm_hessian_inf_shako_nco,itm_hessian_flag_infantry,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_hessen_officer","Hessian Light Infantry","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_hessian_inf_officer,itm_hessian_infantry_pants_officer,itm_hessian_inf_bicorne_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_hessen_horn","Hessian Light Infantry","Hornist",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_hessian_inf_ranker,itm_hessian_infantry_pants,itm_hessian_inf_shako_ranker,itm_horn,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_bavaria","7. Leichtes Infanterie-Battalion, Bayern","Light Infantry/Rifleman",tf_guarantee_all,0,0,fac_rhine,
   [itm_bavarian_jaeger_ranker,itm_austrian_jaeger_pants,itm_bavarian_jaeger_helmet_other_ranks,itm_bullets,itm_french_dragoon_musket,itm_russian_rifle_1805,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_bavaria_nco","Bavarian Rifleman","Sergeant",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_jaeger_nco,itm_austrian_jaeger_pants,itm_bavarian_jaeger_helmet_other_ranks,itm_bullets,itm_french_dragoon_musket,itm_russian_rifle_1805,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,206,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_bavaria_officer","Bavarian Rifleman","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_jaeger_officer,itm_bavarian_pants_officer,itm_bavarian_jaeger_helmet_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_infantry_bavaria_horn","Bavarian Rifleman","Hornist",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_jaeger_hornist,itm_austrian_jaeger_pants,itm_bavarian_jaeger_helmet_other_ranks,itm_horn,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_mounted_jaeger","Reitende Jaeger, Nassau","Hussar",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_nassau_jaeger_ranker,itm_nassau_jaeger_pants,itm_nassau_jaeger_hat_ranker,itm_french_light_cav_sabre,itm_hussar_horse_rhine],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_mounted_jaeger_nco","Nassauer Mounted Jaeger","Sergeant",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_nassau_jaeger_nco,itm_nassau_jaeger_pants,itm_nassau_jaeger_hat_ranker,itm_french_light_cav_sabre,itm_hussar_horse_rhine],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_mounted_jaeger_officer","Nassauer Mounted Jaeger","Officer",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_nassau_jaeger_officer,itm_nassau_jaeger_pants_officer,itm_nassau_jaeger_hat_officer,itm_pistol_ammo,itm_french_pistol_1777,itm_french_light_cav_off_sabre,itm_hussar_horse_rhine,itm_hussar_horse_rhine_officer,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_mounted_jaeger_trumpet","Nassauer Mounted Jaeger","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_nassau_jaeger_trumpet,itm_nassau_jaeger_pants,itm_nassau_jaeger_hat_ranker,itm_trumpet,itm_french_light_cav_sabre,itm_hussar_horse_rhine,itm_hussar_horse_rhine_officer],
   def_attrib|level(20),wpex(160,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_uhlan","Ulanen Regiment Prinz Clemens, Sachsen","Lancer",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_saxon_uhlan_ranker,itm_saxon_uhlan_ranker_alt,itm_saxon_uhlan_pants,itm_saxon_uhlan_pants_alt,itm_saxon_uhlan_shako_ranker,itm_saxon_uhlan_shako_ranker_alt,itm_fr_cuirassier_gloves,itm_saxon_lance,itm_french_light_cav_sabre,itm_lancer_horse_rhine],
   def_attrib|level(20),wpex(50,5,130,5,40,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_uhlan_nco","Saxon Uhlan","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_uhlan_nco,itm_saxon_uhlan_pants,itm_saxon_uhlan_shako_nco,itm_fr_cuirassier_gloves,itm_saxon_flag_uhlan,itm_french_light_cav_sabre,itm_lancer_horse_rhine],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_uhlan_officer","Saxon Uhlan","Officer",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_uhlan_officer,itm_saxon_uhlan_pants_officer,itm_saxon_uhlan_shako_officer,itm_fr_cuirassier_gloves,itm_pistol_ammo,itm_french_cav_pistol,itm_french_light_cav_off_sabre,itm_lancer_horse_rhine_officer,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_uhlan_trumpet","Saxon Uhlan","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_uhlan_trumpet,itm_saxon_uhlan_pants,itm_saxon_uhlan_shako_trumpeter,itm_fr_cuirassier_gloves,itm_trumpet,itm_french_light_cav_sabre,itm_lancer_horse_rhine_officer],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_dragoon","Leichtes Dragoner Regiment, Baden","Light Horse",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_baden_dragoon_ranker,itm_badner_helmet_ranker,itm_baden_dragoon_pants,itm_fr_cuirassier_gloves,itm_french_mousquiton_light, itm_russian_dragoon_musket, itm_bullets,itm_french_light_cav_sabre,itm_lightcav_horse_rhine],
   def_attrib|level(20),wpex(110,5,30,5,140,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_dragoon_nco","Badner Light Dragoon","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_baden_dragoon_nco,itm_badner_helmet_flagcarrier,itm_rus_horse_guard_pants,itm_fr_cuirassier_gloves,itm_baden_flag_dragoon,itm_french_light_cav_sabre,itm_lightcav_horse_rhine],
   def_attrib|level(20),wpex(110,5,30,5,140,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_dragoon_officer","Badner Light Dragoon","Officer",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_baden_dragoon_officer,itm_badner_helmet_officer,itm_rus_horse_guard_pants,itm_fr_cuirassier_gloves,itm_pistol_ammo,itm_russian_pistol,itm_french_light_cav_off_sabre,itm_lightcav_horse_rhine,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_light_dragoon_trumpet","Badner Light Dragoon","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_baden_dragoon_trumpet,itm_badner_helmet_trumpeter,itm_baden_dragoon_pants,itm_fr_cuirassier_gloves,itm_trumpet,itm_french_light_cav_sabre,itm_lightcav_horse_rhine],
   def_attrib|level(20),wpex(130,5,30,5,80,5),knows_common|knows_riding_6|knows_ironflesh_2|knows_power_strike_1|knows_athletics_2,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_cuirassier","1er Regiment de Cuirassiers, Westphalen","Cuirassier",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_westphalian_cuirassier_ranker,itm_rus_horse_guard_pants,itm_westphalian_helmet_other_ranks,itm_fr_cuirassier_gloves,itm_french_line_cav_sabre,itm_cuirassier_horse_rhine],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_cuirassier_nco","Westphalian Cuirassier","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_westphalian_cuirassier_colours,itm_rus_horse_guard_pants,itm_westphalian_helmet_flagcarrier,itm_fr_cuirassier_gloves,itm_westphalian_flag_cuirassier,itm_french_line_cav_sabre,itm_cuirassier_horse_rhine],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_cuirassier_officer","Westphalian Cuirassier","Officer",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_westphalian_cuirassier_officer,itm_rus_horse_guard_pants,itm_westphalian_helmet_officer,itm_fr_cuirassier_gloves,itm_french_cav_pistol,itm_pistol_ammo,itm_french_heavy_cav_off_sabre,itm_cuirassier_horse_rhine_officer,itm_spyglass],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_cuirassier_trumpet","Westphalian Cuirassier","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_westphalian_cuirassier_body_trumpeter,itm_rus_horse_guard_pants,itm_westphalian_helmet_trumpeter,itm_fr_cuirassier_gloves,itm_trumpet,itm_french_line_cav_sabre,itm_cuirassier_horse_rhine_officer],
   def_attrib|level(20),wpex(140,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_garde_du_corps","Garde du Corp, Sachsen","Heavy Cavalry",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_saxon_garde_ranker,itm_garde_du_corps_pants_ranker,itm_saxon_helmet_other_ranks,itm_fr_cuirassier_gloves,itm_french_line_cav_sabre,itm_garde_du_corps_horse_rhine],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_garde_du_corps_nco","Saxon Horse Guard","Colour Bearer",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_garde_colours,itm_garde_du_corps_pants,itm_saxon_helmet_flagcarrier,itm_fr_cuirassier_gloves,itm_saxon_flag_garde,itm_french_line_cav_sabre,itm_garde_du_corps_horse_rhine],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_garde_du_corps_officer","Saxon Horse Guard","Officer",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_garde_officer,itm_garde_du_corps_pants,itm_saxon_helmet_officer,itm_fr_cuirassier_gloves,itm_french_cav_pistol,itm_pistol_ammo,itm_french_heavy_cav_off_sabre,itm_garde_du_corps_horse_rhine_officer,itm_spyglass],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_garde_du_corps_trumpet","Saxon Horse Guard","Trumpeter",tf_mounted|tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_saxon_garde_body_trumpeter,itm_garde_du_corps_pants,itm_saxon_helmet_trumpeter,itm_fr_cuirassier_gloves,itm_trumpet,itm_french_line_cav_sabre,itm_garde_du_corps_horse_rhine_officer],
   def_attrib|level(20),wpex(150,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_arty","Artillerie Regiment, Bayern","Artillery",tf_guarantee_all,0,0,fac_rhine,
   [itm_bavarian_artillery_ranker,itm_bavarian_artillery_pants,itm_bavarian_helmet_artillery,itm_ramrod,itm_cannon_lighter,itm_french_sappeur_sword],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_arty_guard","Artillery Guard, Bayern","Artillery Guard",tf_guarantee_all,0,0,fac_rhine_ranks,#patch1115 67/1
   [itm_bavarian_artillery_ranker,itm_bavarian_artillery_pants,itm_bavarian_helmet_artillery,itm_bullets,itm_prussian_musket_1806,itm_french_sappeur_sword],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_arty_nco","Bavarian Artillerist","Artillery Train",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_artillery_train,itm_austrian_jaeger_pants_officer,itm_bavarian_helmet_train,itm_cannon_lighter,itm_french_sappeur_sword,itm_arty_horse_cannon_french,itm_arty_horse_howitzer_french],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_arty_officer","Bavarian Artillerist","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_artillery_officer,itm_bavarian_artillery_pants_officer,itm_bavarian_helmet_artillery_officer,itm_officer_gloves,itm_french_art_off_sword,itm_cannon_lighter,itm_spyglass],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_medic","Medecin de 2e classe, Frankreich","Surgeon",tf_guarantee_all,0,0,fac_rhine,
   [itm_rhine_surgeon,itm_bavarian_pants_officer,itm_rhine_surgeon_hat,itm_russian_sappeur_dagger,itm_bandages],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_sapper","Pioniere, Berg","Engineer",tf_guarantee_all,0,0,fac_rhine,
   [itm_berg_pioneer,itm_berg_pioneer_pants,itm_berg_pioneer_bearskin,itm_fr_cuirassier_gloves,itm_french_sappeur_sword,itm_sapper_axe,itm_construction_hammer,itm_shovel],
   def_attrib_multiplayer|level(20),wpex(70,5,30,5,30,5),knows_common|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["friedrich_august","Friedrich August I, Konig von Sachsen","Commander",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_saxon_king,itm_bavarian_pants_officer,itm_saxonyking_hat,itm_french_line_cav_sabre,itm_garde_du_corps_horse_rhine_officer,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3|knows_athletics_1,swadian_face_middle_1, swadian_face_old_2],

   
   
   
  ["british_arty_commander","Royal Foot Artillery","Officer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_artillery_officer,itm_rus_dragoon_pants1,itm_british_artillery_shako_officer,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_spyglass,itm_ramrod,itm_arty_horse_cannon_british],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["british_arty_alt_commander","Royal Foot Artillery","Officer",tf_guarantee_all,0,0,fac_british_ranks,
   [itm_british_artillery_officer,itm_rus_dragoon_pants1,itm_british_artillery_shako_officer,itm_br_cavalry_gloves_short,itm_british_light_cav_sabre,itm_spyglass,itm_ramrod,itm_arty_horse_howitzer_british],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_arty_commander","L'Artillerie","Officer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_art_officer_body,itm_fr_arty_captain_bottefortes,itm_french_artillery_bearskin_officer,itm_fr_artillery_gloves,itm_french_art_off_sword,itm_spyglass,itm_ramrod,itm_arty_horse_cannon_french],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["french_arty_alt_commander","L'Artillerie","Officer",tf_guarantee_all,0,0,fac_french_ranks,
   [itm_french_art_officer_body,itm_fr_arty_captain_bottefortes,itm_french_artillery_bearskin_officer,itm_fr_artillery_gloves,itm_french_art_off_sword,itm_spyglass,itm_ramrod,itm_arty_horse_howitzer_french],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_arty_commander","36. Regiment der Fussartillerie","Officer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_arty_officer,itm_rus_dragoon_pants1,itm_prussian_arty_shako_officer,itm_russian_officer_sword,itm_officer_gloves,itm_spyglass,itm_ramrod,itm_arty_horse_cannon_prussian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["prussian_arty_alt_commander","36. Regiment der Fussartillerie","Officer",tf_guarantee_all,0,0,fac_prussian_ranks,
   [itm_prussian_arty_officer,itm_rus_dragoon_pants1,itm_prussian_arty_shako_officer,itm_russian_officer_sword,itm_officer_gloves,itm_spyglass,itm_ramrod,itm_arty_horse_howitzer_prussian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_arty_commander","Artillery","Officer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_arty_officer,itm_rus_arty_pants,itm_rus_arty_shako_officer,itm_russian_officer_sword,itm_officer_gloves,itm_spyglass,itm_ramrod,itm_arty_horse_cannon_russian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["russian_arty_alt_commander","Artillery","Officer",tf_guarantee_all,0,0,fac_russian_ranks,
   [itm_russian_arty_officer,itm_rus_arty_pants,itm_rus_arty_shako_officer,itm_russian_officer_sword,itm_officer_gloves,itm_spyglass,itm_ramrod,itm_arty_horse_howitzer_russian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_arty_commander","Prinz zu Lothringen Nr. 7 Artillerie","Officer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_arty_officer,itm_aus_arty_cap_bicorn,itm_austrian_officer_boots,itm_russian_officer_sword,itm_officer_gloves,itm_spyglass,itm_ramrod,itm_arty_horse_cannon_austrian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["austrian_arty_alt_commander","Prinz zu Lothringen Nr. 7 Artillerie","Officer",tf_guarantee_all,0,0,fac_austrian_ranks,
   [itm_austrian_arty_officer,itm_aus_arty_cap_bicorn,itm_austrian_officer_boots,itm_russian_officer_sword,itm_officer_gloves,itm_spyglass,itm_ramrod,itm_arty_horse_howitzer_austrian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_arty_commander","Artillerie, Bayern.","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_artillery_officer,itm_bavarian_artillery_pants_officer,itm_bavarian_helmet_artillery_officer,itm_officer_gloves,itm_french_art_off_sword,itm_spyglass,itm_ramrod,itm_arty_horse_cannon_austrian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["rhine_arty_alt_commander","Artillerie, Bayern.","Officer",tf_guarantee_all,0,0,fac_rhine_ranks,
   [itm_bavarian_artillery_officer,itm_bavarian_artillery_pants_officer,itm_bavarian_helmet_artillery_officer,itm_officer_gloves,itm_french_art_off_sword,itm_spyglass,itm_ramrod,itm_arty_horse_howitzer_austrian],
   def_attrib_multiplayer|level(20),wpex(80,5,30,5,30,5),knows_common|knows_riding_1|knows_ironflesh_3|knows_power_strike_2|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
 
  ["multiplayer_end","{!}multiplayer_end","{!}multiplayer_end", 0, 0, 0, fac_austria, [], 0, 0, 0, 0, 0],
  
  
  # Vincenzo begin
  ["admin_dummy","{!}admin_dummy","{!}admin_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["flags_owned_dummy","{!}flags_owned_dummy","{!}flags_owned_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["entrypoints_dummy","{!}flags_owned_dummy","{!}flags_owned_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["entrypoints_per_flag_dummy","{!}entrypoints_per_flag_dummy","{!}entrypoints_per_flag_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["destroyed_props_dummy","{!}destroyed_props_dummy","{!}destroyed_props_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  
  # Battle royale
  ["royale_item_class_musket_dummy","{!}royale_item_class_musket_dummy","{!}royale_item_class_musket_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_pistol_dummy","{!}royale_item_class_pistol_dummy","{!}royale_item_class_pistol_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_carabine_dummy","{!}royale_item_class_carabine_dummy","{!}royale_item_class_carabine_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_smallsword_dummy","{!}royale_item_class_briquet_dummy","{!}royale_item_class_briquet_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_bigsword_dummy","{!}royale_item_class_offsword_dummy","{!}royale_item_class_offsword_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_bottle_dummy","{!}royale_item_class_bottle_dummy","{!}royale_item_class_bottle_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_axe_dummy","{!}royale_item_class_smallaxe_dummy","{!}royale_item_class_smallaxe_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_spear_dummy","{!}royale_item_class_spear_dummy","{!}royale_item_class_spear_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_club_dummy","{!}royale_item_class_club_dummy","{!}royale_item_class_club_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_tool_dummy","{!}royale_item_class_tool_dummy","{!}royale_item_class_tool_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_ramrod_dummy","{!}royale_item_class_ramrod_dummy","{!}royale_item_class_ramrod_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_lighter_dummy","{!}royale_item_class_lighter_dummy","{!}royale_item_class_lighter_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  #ammo
  ["royale_item_class_ammo_dummy","{!}royale_item_class_ammo_dummy","{!}royale_item_class_ammo_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  #horses
  ["royale_item_class_horse_light_dummy","{!}royale_item_class_horse_light_dummy","{!}royale_item_class_horse_light_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_horse_medium_dummy","{!}royale_item_class_horse_medium_dummy","{!}royale_item_class_horse_medium_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_horse_heavy_dummy","{!}royale_item_class_horse_heavy_dummy","{!}royale_item_class_horse_heavy_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["royale_item_class_horse_arty_dummy","{!}royale_item_class_horse_arty_dummy","{!}royale_item_class_horse_arty_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  
  ["scene_name_dummy","{!}scene_name_dummy","{!}scene_name_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["admin_white_list_dummy","{!}admin_white_list_dummy","{!}admin_white_list_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  # Vincenzo end

    # Beaver begin
  ["troop_check_dummy","{!}troop_check_dummy","{!}troop_check_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["flag_select_dummy","{!}flag_select_dummy","{!}flag_select_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  #["conquest_spawn_dummy","{!}conquest_spawn_dummy","{!}conquest_spawn_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["track_select_dummy","{!}track_select_dummy","{!}track_select_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_battle_dummy","{!}custom_battle_dummy","{!}custom_battle_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["ai_tactics_dummy","{!}ai_tactics_dummy","{!}ai_tactics_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["manual_dummy","{!}manual_dummy","{!}manual_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  # Beaver end
 # ["agents_to_teleport_dummy","{!}destroyed_props_dummy","{!}destroyed_props_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],

  #TEMP for presentation design
  ["x_pos","{!}custom_battle_dummy","{!}custom_battle_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["y_pos","{!}custom_battle_dummy","{!}custom_battle_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["x_size","{!}custom_battle_dummy","{!}custom_battle_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["y_size","{!}custom_battle_dummy","{!}custom_battle_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],


  
  
#modder_props:custom_strings
    #   Names of these troops are for holding custom strings.
    #   To use as scene prop button labels, set custom button's var1 to value of 1-40
    #   and edit the name of troop with corresponding number (custom_string_1 to custom_string_40)

  ["custom_string_1", "Use", "{!}custom_string_1", tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_2", "Use", "{!}custom_string_2", tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_3", "Use", "{!}custom_string_3", tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_4", "Use", "{!}custom_string_4", tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_5", "Use", "{!}custom_string_5", tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_6", "Use", "{!}custom_string_6", tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_7", "Use", "{!}custom_string_7", tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_8", "Use", "{!}custom_string_8", tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_9", "Use", "{!}custom_string_9", tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_10","Use","{!}custom_string_10",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_11","Use","{!}custom_string_11",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_12","Use","{!}custom_string_12",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_13","Use","{!}custom_string_13",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_14","Use","{!}custom_string_14",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_15","Use","{!}custom_string_15",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_16","Use","{!}custom_string_16",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_17","Use","{!}custom_string_17",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_18","Use","{!}custom_string_18",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_19","Use","{!}custom_string_19",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_20","Use","{!}custom_string_20",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_21","Use","{!}custom_string_21",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_22","Use","{!}custom_string_22",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_23","Use","{!}custom_string_23",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_24","Use","{!}custom_string_24",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_25","Use","{!}custom_string_25",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_26","Use","{!}custom_string_26",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_27","Use","{!}custom_string_27",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_28","Use","{!}custom_string_28",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_29","Use","{!}custom_string_29",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_30","Use","{!}custom_string_30",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_31","Use","{!}custom_string_31",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_32","Use","{!}custom_string_32",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_33","Use","{!}custom_string_33",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_34","Use","{!}custom_string_34",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_35","Use","{!}custom_string_35",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_36","Use","{!}custom_string_36",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_37","Use","{!}custom_string_37",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_38","Use","{!}custom_string_38",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_39","Use","{!}custom_string_39",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_string_40","Use","{!}custom_string_40",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
  ["custom_strings_end","{!}custom_strings_end","{!}custom_strings_end", 0, 0, 0, fac_austria, [], 0, 0, 0, 0, 0],
  ["flag_custom_strings_dummy","{!}flag_custom_strings_dummy","{!}flag_custom_strings_dummy",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],  
 

#  ["custom_button_1","{!}custom_button_1","{!}custom_button_1",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_2","{!}custom_button_2","{!}custom_button_2",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_3","{!}custom_button_3","{!}custom_button_3",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_4","{!}custom_button_4","{!}custom_button_4",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_5","{!}custom_button_5","{!}custom_button_5",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_6","{!}custom_button_6","{!}custom_button_6",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_7","{!}custom_button_7","{!}custom_button_7",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_8","{!}custom_button_8","{!}custom_button_8",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_9","{!}custom_button_9","{!}custom_button_9",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_10","{!}custom_button_10","{!}custom_button_10",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
# 
#  ["custom_button_1_1seconds","{!}custom_button_1_1seconds","{!}custom_button_1_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_2_1seconds","{!}custom_button_2_1seconds","{!}custom_button_2_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_3_1seconds","{!}custom_button_3_1seconds","{!}custom_button_3_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_4_1seconds","{!}custom_button_4_1seconds","{!}custom_button_4_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_5_1seconds","{!}custom_button_5_1seconds","{!}custom_button_5_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_6_1seconds","{!}custom_button_6_1seconds","{!}custom_button_6_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_7_1seconds","{!}custom_button_7_1seconds","{!}custom_button_7_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_8_1seconds","{!}custom_button_8_1seconds","{!}custom_button_8_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_9_1seconds","{!}custom_button_9_1seconds","{!}custom_button_9_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_10_1seconds","{!}custom_button_10_1seconds","{!}custom_button_10_1seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  
#  ["custom_button_1_4seconds","{!}custom_button_1_4seconds","{!}custom_button_1_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_2_4seconds","{!}custom_button_2_4seconds","{!}custom_button_2_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_3_4seconds","{!}custom_button_3_4seconds","{!}custom_button_3_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_4_4seconds","{!}custom_button_4_4seconds","{!}custom_button_4_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_5_4seconds","{!}custom_button_5_4seconds","{!}custom_button_5_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_6_4seconds","{!}custom_button_6_4seconds","{!}custom_button_6_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_7_4seconds","{!}custom_button_7_4seconds","{!}custom_button_7_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_8_4seconds","{!}custom_button_8_4seconds","{!}custom_button_8_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_9_4seconds","{!}custom_button_9_4seconds","{!}custom_button_9_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_10_4seconds","{!}custom_button_10_4seconds","{!}custom_button_10_4seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  
#  ["custom_button_1_8seconds","{!}custom_button_1_8seconds","{!}custom_button_1_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_2_8seconds","{!}custom_button_2_8seconds","{!}custom_button_2_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_3_8seconds","{!}custom_button_3_8seconds","{!}custom_button_3_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_4_8seconds","{!}custom_button_4_8seconds","{!}custom_button_4_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_5_8seconds","{!}custom_button_5_8seconds","{!}custom_button_5_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_6_8seconds","{!}custom_button_6_8seconds","{!}custom_button_6_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_7_8seconds","{!}custom_button_7_8seconds","{!}custom_button_7_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_8_8seconds","{!}custom_button_8_8seconds","{!}custom_button_8_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_9_8seconds","{!}custom_button_9_8seconds","{!}custom_button_9_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],
#  ["custom_button_10_8seconds","{!}custom_button_10_8seconds","{!}custom_button_10_8seconds",tf_hero|tf_inactive,0,reserved,fac_neutral,[],def_attrib,0,knows_common,0],

# Quick Battle troops.
  ["quick_battle_troop_britain_1","Arthur Wellesley","General",tf_hero,0,0,fac_britain,
   [itm_british_wellington,itm_british_wellington_pants,itm_british_wellington_bicorne,itm_heavy_horse_britain,itm_french_line_cav_sabre,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_10|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],

  ["quick_battle_troop_france_1","Napoleon Bonaparte","Emperor",tf_hero,0,0,fac_france,
   [itm_french_general_body_boney,itm_french_general_boots,itm_french_nappy_hat,itm_french_line_cav_sabre,itm_carabineer_horse_french_officer,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_10|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
#  ["quick_battle_troop_france_2","Marshal Lannes","Marshal",tf_hero,0,0,fac_france,
#   [itm_french_art_officer_body,itm_french_voltigeur_officer_pants,itm_french_inf_bicorne_45_officer,itm_french_line_cav_sabre,itm_heavy_horse_placeholder,itm_officer_gloves],
#   def_attrib|level(20),wpex(150,5,30,5,80,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3,0x000000002004400436db6db8cba1bafa00000000001eb6db0000000000000000, swadian_face_old_2],
#  ["quick_battle_troop_france_3","Marshal Murat","Marshal",tf_hero,0,0,fac_france,
#   [itm_french_art_officer_body,itm_french_voltigeur_officer_pants,itm_french_line_cav_sabre,itm_heavy_horse_placeholder,itm_officer_gloves],
#   def_attrib|level(20),wpex(150,5,30,5,80,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3,0x000000002004400436db6db8cba1bafa00000000001eb6db0000000000000000, swadian_face_old_2],
  
  ["quick_battle_troop_prussia_1","Gebhard von Blucher","General",tf_hero,0,0,fac_prussia,
   [itm_prussian_blucher,itm_prussian_blucher_pants,itm_prussian_blucher_hat,itm_russian_guard_sword_1799,itm_heavy_horse_prussia_1,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_10|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  
  ["quick_battle_troop_russia_1","Mikhail Kutuzov","General",tf_hero,0,0,fac_russia,
   [itm_kutuzov,itm_rus_kutuzov_pants,itm_kutuzov_hat,itm_russian_guard_sword_1799,itm_heavy_horse_russia,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_10|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],   
  
  ["quick_battle_troop_austria_1","Karl Philipp","General",tf_mounted|tf_guarantee_all,0,0,fac_austria,
   [itm_austrian_schwarzenberg,itm_austrian_schwarzenberg_pants,itm_aus_shwarzenberg_bicorn,itm_british_heavy_cav_sword,itm_heavy_horse_austria,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_10|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],   
   
  ["quick_battle_troop_rhine_1","Friedrich August","General",tf_mounted|tf_guarantee_all,0,0,fac_rhine,
   [itm_french_general_body_boney,itm_french_general_boots,itm_french_nappy_hat,itm_french_line_cav_sabre,itm_carabineer_horse_french_officer,itm_officer_gloves,itm_spyglass],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_6|knows_ironflesh_5|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],

   ["quick_battle_troops_end","{!}quick_battle_troops_end","{!}quick_battle_troops_end", 0, 0, 0, fac_austria, [], 0, 0, 0, 0, 0],

 
  # Companions
  
  # Infantry
  ["companion_1","Raphael Martin","Raphael Martin",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x0000000fed0c14c3449c0238764b126a00000000000ec70c0000000000000000],
   
  ["companion_2","Clement Bernard","Clement Bernard",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x0000000fcd04408d459c08d52560a89300000000001557620000000000000000],
   
  ["companion_3","Maxim Munnig Schmidt","Maxime Petit",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x00000007fa00149437156eb6938ea8d600000000000616eb0000000000000000],
   
  ["companion_4","Alexandre Durand","Alexandre Durand",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x00000007d71041072716ab34749339b400000000000f248e0000000000000000],
   
  ["companion_5","Antoine Richard","Antoine Richard",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x00000007dd10158228dc6e2b128e349e000000000004b51a0000000000000000],
   
  ["companion_6","Alexis Moreau","Alexis Moreau",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x00000007f000358b491fc9129c912d7500000000000cc8c30000000000000000],
   
  ["companion_7","Jules Dubois","Jules Dubois",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x000000026a044287255d65994a494312000000000011acdc0000000000000000],
   
  ["companion_8","Matteo Robert","Matteo Robert",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x0000000e871022496caa66e72be5d8b5000000000009df1c0000000000000000],
   
  ["companion_9","Julien Laurent","Julien Laurent",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x0000000e841011c2359275ca9e92390b0000000000124acb0000000000000000],
   
  ["companion_10","Samuel Simon","Samuel Simon",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x00000009300852c936948a32be69aa6d00000000001235220000000000000000],
   
  ["companion_11","Noe Michel","Noe Michel",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x0000000d6f040043231c8db524c9dcea00000000000e44d30000000000000000],
   
  ["companion_12","Corentin Leroy","Corentin Leroy",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x00000000121045c854e450b4f5c0993600000000000ac7430000000000000000],
   
  ["companion_13","Jeremy Garcia","Jeremy Garcia",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x00000000210420892f0b65aaa432c695000000000011a52e0000000000000000],
   
  ["companion_14","Charles Lefebvre","Charles Lefebvre",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x000000002c10248244a98a475d39392300000000000cb5740000000000000000],
   
  ["companion_15","Eliott Roux","Eliott Roux",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib|level(20),wpex(50,5,130,5,150,5),
   knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,
   0x000000048c0801cc44a34e277c6754ec00000000000fc85a0000000000000000],
  
  
  # Caverly
  ["companion_16","Theo David","Theo David",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000b960054c559e46b5b8cb9d2ce000000000010d92c0000000000000000],
  
  ["companion_17","Romain Bertrand","Romain Bertrand",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000bb80445c8146e843799375cd500000000001337440000000000000000],
  
  ["companion_18","Quentin Fournier","Quentin Fournier",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000ba80843d05731719a5255a8910000000000152d530000000000000000],
  
  ["companion_19","Girard Baptiste","Girard Baptiste",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000dc40c4193492d6e46e197689200000000000dc3550000000000000000],
  
  ["companion_20","Valentin Bonnet","Valentin Bonnet",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000fc404444e5b4a89b65d6dc6ec00000000000916e50000000000000000],
  
  ["companion_21","Nico Kamps","Nicolas Morel",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000d870054463b4b2f5c9e8f66d5000000000018b5250000000000000000],
  
  ["companion_22","Mael Rousseau","Mael Rousseau",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000dae0011102d6452b892f5355c0000000000165cac0000000000000000],
  
  ["companion_23","Pierre Lambert","Pierre Lambert",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x000000097704440f29295268a4b632f3000000000012aaec0000000000000000],
  
  ["companion_24","Marius Blanc","Marius Blanc",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x000000097d0c204726fe70b6fb8a671b00000000000dc28a0000000000000000],
  
  ["companion_25","Remi Thomas","Remi Thomas",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x000000049600544c58e24a35590e87a3000000000009264c0000000000000000],
  
  ["companion_26","Benjamin Aguillon","Benjamin Aguillon",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000d2710310844dd6f559371caf300000000000e170c0000000000000000],
  
  ["companion_27","Maxence Beauregard","Maxence Beauregard",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x00000007850c434845266ec85592d2cd000000000009dcad0000000000000000],
  
  ["companion_28","Axel Lemieux","Axel Lemieux",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x00000007921043c656a32b34c4498714000000000009a2a30000000000000000],
  
  ["companion_29","Jules Plantier","Jules Plantier",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000db30c044f48ed72351a894997000000000009b69c0000000000000000],
  
  ["companion_30","Martin Roche","Martin Roche",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_dragoon_body_ranker,itm_french_dragoon_pants,itm_french_dragoon_helmet,itm_french_dragoon_musket,itm_bullets,itm_french_heavy_cav_sabre_garde,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(110,5,30,5,125,5),
   knows_common|knows_riding_5|knows_ironflesh_3|knows_power_strike_3,
   0x0000000db9082312159536295b653cc600000000001b169c0000000000000000],
  
  ["companions_end","companions_end","companions_end",tf_hero|tf_unmoveable_in_party_window,0,reserved,fac_commoners,
   [itm_french_hussar_shako_ranker,itm_french_light_cav_sabre,itm_dragoon_horse_placeholder],
   def_attrib|level(20),wpex(150,5,30,5,30,5),
   knows_common|knows_riding_6|knows_ironflesh_3|knows_power_strike_3,
   0x0000000db9082312159536295b653cc600000000001b169c0000000000000000],
  
  
  ["walker_french_infantry","Infantryman","Infantry",tf_guarantee_all,0,0,fac_commoners,
   [itm_french_45e_body_ranker,itm_french_voltigeur_officer_pants,itm_french_inf_shako_45_ranker,itm_bullets,itm_french_charleville],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["walker_french_voltigeur","Voltigeur","Voltigeurs",tf_guarantee_all,0,0,fac_commoners,
   [itm_french_voltigeur_body_ranker,itm_french_voltigeur_officer_pants,itm_french_voltigeur_pants,itm_french_voltigeur_shako_ranker,itm_bullets,itm_french_charleville,itm_french_briquet],
   def_attrib_multiplayer|level(20),wpex(50,5,90,5,150,5),knows_common|knows_ironflesh_2|knows_power_strike_1|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["walker_french_hussar","Hussar","Hussars",tf_mounted|tf_guarantee_all,0,0,fac_commoners,
   [itm_russian_hussar_ranker,itm_rus_hussar_pants_nco,itm_french_hussar_shako_ranker,itm_french_light_cav_sabre],
   def_attrib|level(20),wpex(130,5,30,5,30,5),knows_common|knows_riding_4|knows_ironflesh_3|knows_power_strike_3,swadian_face_middle_1, swadian_face_old_2],
  ["walker_french_officer","Officer","officers",tf_guarantee_all,0,0,fac_commoners,
   [itm_french_45e_body_officer,itm_french_voltigeur_officer_pants,itm_french_inf_bicorne_45_officer,itm_french_inf_off_sabre,itm_pistol_ammo,itm_french_officer_pistol,itm_french_pistol_1766,itm_officer_gloves],
   def_attrib_multiplayer|level(20),wpex(80,5,80,5,50,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["walker_messenger","Messenger","Messenger",tf_guarantee_all,0,0,fac_commoners,
   [itm_french_gap_body_officer,itm_french_voltigeur_officer_pants],
   def_attrib|level(20),wpex(50,5,130,5,120,5),knows_common|knows_ironflesh_3|knows_power_strike_3|knows_athletics_3,swadian_face_middle_1, swadian_face_old_2],
  ["walker_peasant_male","Peasant","Peasants",tf_guarantee_all,0,0,fac_commoners,
   [itm_rus_partizan1,itm_rus_partizan2,itm_rus_militia_ranker_pants,itm_rus_militia_ranker_pants1,itm_rus_partisan_hat1,itm_rus_partisan_hat2,itm_rus_partisan_hat3,itm_rus_partisan_hat4,itm_rus_partisan_hat5],
   def_attrib|level(4),wp(60),knows_common,man_face_middle_1, man_face_old_2],
  ["walker_peasant_female","Peasant", "Peasants",tf_female|tf_guarantee_all,0,0, fac_commoners,
   [],
   def_attrib|level(4),wp(60),knows_common, 0x00000000ef00000237dc71b90c31631200000000001e371b0000000000000000, 0x000000050b003004072d51c293a9a70b00000000001dd6a90000000000000000],   
  ["walkers_end","walkers_end","walkers_end",tf_hero, 0,0, fac_commoners,[],def_attrib|level(2),wp(20),knows_inventory_management_10,0],
 
# Merchants
  ["camp_armorer","Tailor","{!}Armorer",  tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners,
  [itm_french_dragoon_pants,itm_french_artillery_train_shako,itm_french_briquet],
  def_attrib|level(2),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2],
  ["camp_weaponsmith", "Weapon Merchant","{!}Weaponsmith",tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners,
  [itm_french_dragoon_pants,itm_french_artillery_train_shako,itm_french_briquet],
  def_attrib|level(5),wp(20),knows_inventory_management_10, mercenary_face_1, mercenary_face_2],
  ["camp_horse_merchant","Horse Merchant","{!}Horse Merchant",tf_hero|tf_randomize_face|tf_is_merchant, 0, 0, fac_commoners,
  [itm_french_dragoon_pants,itm_french_artillery_train_shako,itm_french_briquet],
  def_attrib|level(5),wp(20),knows_inventory_management_10, man_face_young_1, man_face_older_2],
  ["merchants_end","merchants_end","merchants_end",tf_hero, 0,0, fac_commoners,[],def_attrib|level(2),wp(20),knows_inventory_management_10,0],
  
]


#Troop upgrade declarations



